@@ -7,31 +7,33 @@ import type { MergedRollupOptions } from '../../src/rollup/types';
 import { bold } from '../../src/utils/colors';
 import {
 	error,
-	errorCannotBundleConfigAsEsm,
-	errorCannotLoadConfigAsCjs,
-	errorCannotLoadConfigAsEsm,
-	errorMissingConfig
-} from '../../src/utils/error';
+	logCannotBundleConfigAsEsm,
+	logCannotLoadConfigAsCjs,
+	logCannotLoadConfigAsEsm,
+	logMissingConfig
+} from '../../src/utils/logs';
 import { mergeOptions } from '../../src/utils/options/mergeOptions';
 import type { GenericConfigObject } from '../../src/utils/options/options';
 import relativeId from '../../src/utils/relativeId';
 import { stderr } from '../logging';
-import batchWarnings, { type BatchWarnings } from './batchWarnings';
+import batchWarnings from './batchWarnings';
 import { addCommandPluginsToInputOptions, addPluginsFromCommandOption } from './commandPlugins';
+import type { LoadConfigFile } from './loadConfigFileType';
 
-export async function loadConfigFile(
-	fileName: string,
-	commandOptions: any = {}
-): Promise<{ options: MergedRollupOptions[]; warnings: BatchWarnings }> {
+export const loadConfigFile: LoadConfigFile = async (
+	fileName,
+	commandOptions = {},
+	watchMode = false
+) => {
 	const configs = await getConfigList(
-		getDefaultFromCjs(await getConfigFileExport(fileName, commandOptions)),
+		getDefaultFromCjs(await getConfigFileExport(fileName, commandOptions, watchMode)),
 		commandOptions
 	);
-	const warnings = batchWarnings();
+	const warnings = batchWarnings(commandOptions);
 	try {
 		const normalizedConfigs: MergedRollupOptions[] = [];
 		for (const config of configs) {
-			const options = await mergeOptions(config, commandOptions, warnings.add);
+			const options = await mergeOptions(config, watchMode, commandOptions, warnings.log);
 			await addCommandPluginsToInputOptions(options, commandOptions);
 			normalizedConfigs.push(options);
 		}
@@ -40,15 +42,19 @@ export async function loadConfigFile(
 		warnings.flush();
 		throw error_;
 	}
-}
+};
 
-async function getConfigFileExport(fileName: string, commandOptions: Record<string, unknown>) {
+async function getConfigFileExport(
+	fileName: string,
+	commandOptions: Record<string, unknown>,
+	watchMode: boolean
+) {
 	if (commandOptions.configPlugin || commandOptions.bundleConfigAsCjs) {
 		try {
 			return await loadTranspiledConfigFile(fileName, commandOptions);
 		} catch (error_: any) {
 			if (error_.message.includes('not defined in ES module scope')) {
-				return error(errorCannotBundleConfigAsEsm(error_));
+				return error(logCannotBundleConfigAsEsm(error_));
 			}
 			throw error_;
 		}
@@ -62,17 +68,17 @@ async function getConfigFileExport(fileName: string, commandOptions: Record<stri
 	process.on('warning', handleWarning);
 	try {
 		const fileUrl = pathToFileURL(fileName);
-		if (process.env.ROLLUP_WATCH) {
+		if (watchMode) {
 			// We are adding the current date to allow reloads in watch mode
 			fileUrl.search = `?${Date.now()}`;
 		}
 		return (await import(fileUrl.href)).default;
 	} catch (error_: any) {
 		if (cannotLoadEsm) {
-			return error(errorCannotLoadConfigAsCjs(error_));
+			return error(logCannotLoadConfigAsCjs(error_));
 		}
 		if (error_.message.includes('not defined in ES module scope')) {
-			return error(errorCannotLoadConfigAsEsm(error_));
+			return error(logCannotLoadConfigAsEsm(error_));
 		}
 		throw error_;
 	} finally {
@@ -86,9 +92,10 @@ function getDefaultFromCjs(namespace: GenericConfigObject): unknown {
 
 async function loadTranspiledConfigFile(
 	fileName: string,
-	{ bundleConfigAsCjs, configPlugin, silent }: Record<string, unknown>
+	commandOptions: Record<string, unknown>
 ): Promise<unknown> {
-	const warnings = batchWarnings();
+	const { bundleConfigAsCjs, configPlugin, silent } = commandOptions;
+	const warnings = batchWarnings(commandOptions);
 	const inputOptions = {
 		external: (id: string) =>
 			(id[0] !== '.' && !isAbsolute(id)) || id.slice(-5, id.length) === '.json',
@@ -99,10 +106,6 @@ async function loadTranspiledConfigFile(
 	};
 	await addPluginsFromCommandOption(configPlugin, inputOptions);
 	const bundle = await rollup.rollup(inputOptions);
-	if (!silent && warnings.count > 0) {
-		stderr(bold(`loaded ${relativeId(fileName)} with warnings`));
-		warnings.flush();
-	}
 	const {
 		output: [{ code }]
 	} = await bundle.generate({
@@ -122,6 +125,10 @@ async function loadTranspiledConfigFile(
 			}
 		]
 	});
+	if (!silent && warnings.count > 0) {
+		stderr(bold(`loaded ${relativeId(fileName)} with warnings`));
+		warnings.flush();
+	}
 	return loadConfigFromWrittenFile(
 		join(dirname(fileName), `rollup.config-${Date.now()}.${bundleConfigAsCjs ? 'cjs' : 'mjs'}`),
 		code
@@ -146,7 +153,7 @@ async function getConfigList(configFileExport: any, commandOptions: any): Promis
 		? configFileExport(commandOptions)
 		: configFileExport);
 	if (Object.keys(config).length === 0) {
-		return error(errorMissingConfig());
+		return error(logMissingConfig());
 	}
 	return Array.isArray(config) ? config : [config];
 }
