@@ -29,9 +29,27 @@ interface OptionTypeStringMapping extends BaseOptionType<Record<string, string>>
 	type: 'string-mapping';
 }
 
-type OptionType = OptionTypeSelect<unknown> | OptionTypeString | OptionTypeStringMapping;
+interface OptionTypeNumber extends BaseOptionType<number> {
+	placeholder: string | null;
+	type: 'number';
+}
+
+type OptionType =
+	| OptionTypeSelect<unknown>
+	| OptionTypeString
+	| OptionTypeStringMapping
+	| OptionTypeNumber;
 
 const mapOptions = {
+	number({ defaultValue, name, placeholder, required, value }: OptionTypeNumber) {
+		return {
+			name,
+			placeholder,
+			removable: !required.value,
+			type: 'number',
+			value: value.value === undefined ? defaultValue : value.value
+		} as const;
+	},
 	select({ defaultValue, name, options, required, value }: OptionTypeSelect<unknown>) {
 		return {
 			name,
@@ -118,7 +136,7 @@ export const useOptions = defineStore('options2', () => {
 		name: 'output.amd.define'
 	});
 	const optionOutputAmdForceJsExtensionForImports = getBoolean({
-		available: () => isAmdFormat.value && outputHasMultipleChunks.value,
+		available: isAmdFormat,
 		name: 'output.amd.forceJsExtensionForImports'
 	});
 	const optionOutputAmdId = getString({
@@ -131,7 +149,7 @@ export const useOptions = defineStore('options2', () => {
 		name: 'output.banner'
 	});
 	const optionOutputChunkFileNames = getString({
-		available: outputHasMultipleChunks,
+		available: alwaysTrue,
 		defaultValue: '[name]-[hash].js',
 		name: 'output.chunkFileNames'
 	});
@@ -144,7 +162,7 @@ export const useOptions = defineStore('options2', () => {
 		name: 'output.dynamicImportInCjs'
 	});
 	const optionOutputEntryFileNames = getString({
-		available: outputHasMultipleChunks,
+		available: alwaysTrue,
 		defaultValue: '[name].js',
 		name: 'output.entryFileNames'
 	});
@@ -154,6 +172,10 @@ export const useOptions = defineStore('options2', () => {
 		name: 'output.esModule',
 		options: () => [false, true, 'if-default-prop']
 	});
+	const optionOutputExperimentalMinChunkSize = getNumber({
+		defaultValue: 0,
+		name: 'output.experimentalMinChunkSize'
+	});
 	const optionOutputExports = getSelect({
 		available: isInteropFormat,
 		defaultValue: 'auto',
@@ -218,7 +240,7 @@ export const useOptions = defineStore('options2', () => {
 		required: () => true
 	});
 	const optionOutputHoistTransitiveImports = getBoolean({
-		available: outputHasMultipleChunks,
+		available: alwaysTrue,
 		defaultValue: true,
 		name: 'output.hoistTransitiveImports'
 	});
@@ -257,7 +279,7 @@ export const useOptions = defineStore('options2', () => {
 		name: 'output.intro'
 	});
 	const optionOutputMinifyInternalExports = getBoolean({
-		available: outputHasMultipleChunks,
+		available: alwaysTrue,
 		name: 'output.minifyInternalExports'
 	});
 	const optionOutputNoConflict = getBoolean({
@@ -289,14 +311,14 @@ export const useOptions = defineStore('options2', () => {
 		available: optionOutputPreserveModules.value,
 		name: 'output.preserveModulesRoot'
 	});
-	const optionOutputSourcemap = getBoolean({
-		name: 'output.sourcemap'
-	});
 	const optionOutputSanitizeFileName = getBoolean({
-		available: outputHasMultipleChunks,
+		available: alwaysTrue,
 		defaultValue: true,
 		name: 'output.sanitizeFileName'
 	});
+	const optionOutputSourcemap = getBoolean({
+		name: 'output.sourcemap'
+	});
 	const optionOutputSourcemapBaseUrl = getString({
 		available: optionOutputSourcemap.value,
 		name: 'output.sourcemapBaseUrl'
@@ -305,26 +327,31 @@ export const useOptions = defineStore('options2', () => {
 		available: optionOutputSourcemap.value,
 		name: 'output.sourcemapExcludeSources'
 	});
+	const optionOutputSourcemapFileNames = getString({
+		available: alwaysTrue,
+		defaultValue: undefined,
+		name: 'output.sourcemapFileNames'
+	});
 	const optionOutputStrict = getBoolean({
 		available: () =>
 			optionOutputFormat.value.value !== undefined && optionOutputFormat.value.value !== 'es',
 		defaultValue: true,
 		name: 'output.strict'
 	});
-	const optionOutputValidate = getBoolean({
-		name: 'output.validate'
-	});
-	const optionPreserveEntrySignatures = getSelect({
-		available: outputHasMultipleChunks,
-		defaultValue: 'exports-only',
-		name: 'preserveEntrySignatures',
-		options: () => ['strict', 'allow-extension', 'exports-only', false]
-	});
 	const optionOutputSystemNullSetters = getBoolean({
 		available: () => optionOutputFormat.value.value === 'system',
 		defaultValue: true,
 		name: 'output.systemNullSetters'
 	});
+	const optionOutputValidate = getBoolean({
+		name: 'output.validate'
+	});
+	const optionPreserveEntrySignatures = getSelect({
+		available: alwaysTrue,
+		defaultValue: 'exports-only',
+		name: 'preserveEntrySignatures',
+		options: () => ['strict', 'allow-extension', 'exports-only', false]
+	});
 	const optionShimMissingExports = getBoolean({
 		defaultValue: false,
 		name: 'shimMissingExports'
@@ -386,6 +413,7 @@ export const useOptions = defineStore('options2', () => {
 		optionOutputDynamicImportInCjs,
 		optionOutputEntryFileNames,
 		optionOutputEsModule,
+		optionOutputExperimentalMinChunkSize,
 		optionOutputExports,
 		optionOutputExtend,
 		optionOutputExternalLiveBindings,
@@ -413,6 +441,7 @@ export const useOptions = defineStore('options2', () => {
 		optionOutputPreserveModules,
 		optionOutputPreserveModulesRoot,
 		optionOutputSourcemap,
+		optionOutputSourcemapFileNames,
 		optionOutputSanitizeFileName,
 		optionOutputSourcemapBaseUrl,
 		optionOutputSourcemapExcludeSources,
@@ -553,6 +582,30 @@ function getStringMapping({
 	};
 }
 
+function getNumber({
+	available,
+	defaultValue,
+	name,
+	placeholder,
+	required
+}: {
+	available?: (() => boolean) | Ref<boolean | undefined>;
+	defaultValue?: number;
+	name: string;
+	placeholder?: string;
+	required?: () => boolean;
+}): OptionTypeNumber {
+	return {
+		available: typeof available === 'function' ? computed(available) : available || alwaysTrue,
+		defaultValue: defaultValue ?? 0,
+		name,
+		placeholder: placeholder || null,
+		required: required ? computed(required) : alwaysFalse,
+		type: 'number',
+		value: ref(undefined)
+	};
+}
+
 function getOptionsObject(options: Ref<Option[]>): Ref<RollupOptions> {
 	let previousOptions = options.value.filter(({ value }) => value !== undefined);
 	const result = shallowRef<RollupOptions>({});
