@@ -1,8 +1,8 @@
 /* eslint-disable no-console */
 
+import { rmSync } from 'node:fs';
 import { argv, chdir, exit } from 'node:process';
 import { fileURLToPath } from 'node:url';
-import fs from 'fs-extra';
 import { findConfigFileName } from './find-config.js';
 import { runWithEcho } from './helpers.js';
 
@@ -19,7 +19,10 @@ if (argv.length !== 3 || !VALID_REPO.test(repoWithBranch)) {
 }
 
 console.error(`Cleaning up '${TARGET_DIR}'...`);
-fs.removeSync(TARGET_DIR);
+rmSync(TARGET_DIR, {
+	force: true,
+	recursive: true
+});
 
 const [, repo, , branch] = VALID_REPO.exec(repoWithBranch);
 
