@@ -17,16 +17,17 @@ import type {
 import { PluginDriver } from './utils/PluginDriver';
 import Queue from './utils/Queue';
 import { BuildPhase } from './utils/buildPhase';
+import { addAnnotations } from './utils/commentAnnotations';
+import { analyseModuleExecution } from './utils/executionOrder';
+import { LOGLEVEL_WARN } from './utils/logging';
 import {
 	error,
-	errorCircularDependency,
-	errorImplicitDependantIsNotIncluded,
-	errorMissingExport
-} from './utils/error';
-import { analyseModuleExecution } from './utils/executionOrder';
-import { addAnnotations } from './utils/pureComments';
-import { getPureFunctions } from './utils/pureFunctions';
+	logCircularDependency,
+	logImplicitDependantIsNotIncluded,
+	logMissingExport
+} from './utils/logs';
 import type { PureFunctions } from './utils/pureFunctions';
+import { getPureFunctions } from './utils/pureFunctions';
 import { timeEnd, timeStart } from './utils/timers';
 import { markModuleAndImpureDependenciesAsExecuted } from './utils/traverseStaticDependencies';
 
@@ -73,7 +74,10 @@ export default class Graph {
 	private modules: Module[] = [];
 	private declare pluginCache?: Record<string, SerializablePluginCache>;
 
-	constructor(private readonly options: NormalizedInputOptions, watcher: RollupWatcher | null) {
+	constructor(
+		private readonly options: NormalizedInputOptions,
+		watcher: RollupWatcher | null
+	) {
 		if (options.cache !== false) {
 			if (options.cache?.modules) {
 				for (const module of options.cache.modules) this.cachedModules.set(module.id, module);
@@ -187,7 +191,8 @@ export default class Graph {
 	}
 
 	private includeStatements(): void {
-		for (const module of [...this.entryModules, ...this.implicitEntryModules]) {
+		const entryModules = [...this.entryModules, ...this.implicitEntryModules];
+		for (const module of entryModules) {
 			markModuleAndImpureDependenciesAsExecuted(module);
 		}
 		if (this.options.treeshake) {
@@ -207,7 +212,7 @@ export default class Graph {
 				if (treeshakingPass === 1) {
 					// We only include exports after the first pass to avoid issues with
 					// the TDZ detection logic
-					for (const module of [...this.entryModules, ...this.implicitEntryModules]) {
+					for (const module of entryModules) {
 						if (module.preserveSignature !== false) {
 							module.includeAllExports(false);
 							this.needsTreeshakingPass = true;
@@ -223,7 +228,7 @@ export default class Graph {
 		for (const module of this.implicitEntryModules) {
 			for (const dependant of module.implicitlyLoadedAfter) {
 				if (!(dependant.info.isEntry || dependant.isIncluded())) {
-					error(errorImplicitDependantIsNotIncluded(dependant));
+					error(logImplicitDependantIsNotIncluded(dependant));
 				}
 			}
 		}
@@ -232,7 +237,7 @@ export default class Graph {
 	private sortModules(): void {
 		const { orderedModules, cyclePaths } = analyseModuleExecution(this.entryModules);
 		for (const cyclePath of cyclePaths) {
-			this.options.onwarn(errorCircularDependency(cyclePath));
+			this.options.onLog(LOGLEVEL_WARN, logCircularDependency(cyclePath));
 		}
 		this.modules = orderedModules;
 		for (const module of this.modules) {
@@ -248,8 +253,9 @@ export default class Graph {
 					importDescription.name !== '*' &&
 					!importDescription.module.getVariableForExportName(importDescription.name)[0]
 				) {
-					module.warn(
-						errorMissingExport(importDescription.name, module.id, importDescription.module.id),
+					module.log(
+						LOGLEVEL_WARN,
+						logMissingExport(importDescription.name, module.id, importDescription.module.id),
 						importDescription.start
 					);
 				}
