@@ -33,6 +33,7 @@ import type {
 	DecodedSourceMapOrMissing,
 	EmittedFile,
 	ExistingDecodedSourceMap,
+	LogLevel,
 	ModuleInfo,
 	ModuleJSON,
 	ModuleOptions,
@@ -43,30 +44,31 @@ import type {
 	ResolvedIdMap,
 	RollupError,
 	RollupLog,
-	RollupWarning,
 	TransformModuleJSON
 } from './rollup/types';
 import { EMPTY_OBJECT } from './utils/blank';
 import { BuildPhase } from './utils/buildPhase';
-import {
-	augmentCodeLocation,
-	error,
-	errorAmbiguousExternalNamespaces,
-	errorCircularReexport,
-	errorInconsistentImportAssertions,
-	errorInvalidFormatForTopLevelAwait,
-	errorInvalidSourcemapForError,
-	errorMissingExport,
-	errorNamespaceConflict,
-	errorParseError,
-	errorShimmedExport,
-	errorSyntheticNamedExportsNeedNamespaceExport,
-	warnDeprecation
-} from './utils/error';
+import { decodedSourcemap, resetSourcemapCache } from './utils/decodedSourcemap';
 import { getId } from './utils/getId';
 import { getNewSet, getOrCreate } from './utils/getOrCreate';
 import { getOriginalLocation } from './utils/getOriginalLocation';
 import { makeLegal } from './utils/identifierHelpers';
+import { LOGLEVEL_WARN } from './utils/logging';
+import {
+	augmentCodeLocation,
+	error,
+	logAmbiguousExternalNamespaces,
+	logCircularReexport,
+	logInconsistentImportAssertions,
+	logInvalidFormatForTopLevelAwait,
+	logInvalidSourcemapForError,
+	logMissingExport,
+	logNamespaceConflict,
+	logParseError,
+	logShimmedExport,
+	logSyntheticNamedExportsNeedNamespaceExport,
+	warnDeprecation
+} from './utils/logs';
 import {
 	doAssertionsDiffer,
 	getAssertionsFromImportExportDeclaration
@@ -118,6 +120,7 @@ export interface AstContext {
 	includeAllExports: () => void;
 	includeDynamicImport: (node: ImportExpression) => void;
 	includeVariableInModule: (variable: Variable) => void;
+	log: (level: LogLevel, properties: RollupLog, pos: number) => void;
 	magicString: MagicString;
 	manualPureFunctions: PureFunctions;
 	module: Module; // not to be used for tree-shaking
@@ -127,7 +130,6 @@ export interface AstContext {
 	traceExport: (name: string) => Variable | null;
 	traceVariable: (name: string) => Variable | null;
 	usesTopLevelAwait: boolean;
-	warn: (warning: RollupWarning, pos: number) => void;
 }
 
 export interface DynamicImport {
@@ -152,7 +154,7 @@ function getVariableForExportNameRecursive(
 	const searchedModules = searchedNamesAndModules.get(name);
 	if (searchedModules) {
 		if (searchedModules.has(target)) {
-			return isExportAllSearch ? [null] : error(errorCircularReexport(name, target.id));
+			return isExportAllSearch ? [null] : error(logCircularReexport(name, target.id));
 		}
 		searchedModules.add(target);
 	} else {
@@ -166,10 +168,10 @@ function getVariableForExportNameRecursive(
 }
 
 function getAndExtendSideEffectModules(variable: Variable, module: Module): Set<Module> {
-	const sideEffectModules = getOrCreate<Variable, Set<Module>>(
+	const sideEffectModules = getOrCreate(
 		module.sideEffectDependenciesByVariable,
 		variable,
-		getNewSet
+		getNewSet<Module>
 	);
 	let currentVariable: Variable | null = variable;
 	const referencedVariables = new Set([currentVariable]);
@@ -401,6 +403,17 @@ export default class Module {
 		return error(properties);
 	}
 
+	// sum up the length of all ast nodes that are included
+	estimateSize(): number {
+		let size = 0;
+		for (const node of this.ast!.body) {
+			if (node.included) {
+				size += node.end - node.start;
+			}
+		}
+		return size;
+	}
+
 	getAllExportNames(): Set<string> {
 		if (this.allExportNames) {
 			return this.allExportNames;
@@ -440,7 +453,7 @@ export default class Module {
 		) {
 			for (const exportName of [...this.getReexports(), ...this.getExports()]) {
 				const [exportedVariable] = this.getVariableForExportName(exportName);
-				if (exportedVariable) {
+				if (exportedVariable?.included) {
 					dependencyVariables.add(exportedVariable);
 				}
 			}
@@ -550,7 +563,7 @@ export default class Module {
 		}
 		if (!this.syntheticNamespace) {
 			return error(
-				errorSyntheticNamedExportsNeedNamespaceExport(this.id, this.info.syntheticNamedExports)
+				logSyntheticNamedExportsNeedNamespaceExport(this.id, this.info.syntheticNamedExports)
 			);
 		}
 		return this.syntheticNamespace;
@@ -592,12 +605,19 @@ export default class Module {
 			);
 			if (!variable) {
 				return this.error(
-					errorMissingExport(reexportDeclaration.localName, this.id, reexportDeclaration.module.id),
+					logMissingExport(reexportDeclaration.localName, this.id, reexportDeclaration.module.id),
 					reexportDeclaration.start
 				);
 			}
 			if (importerForSideEffects) {
 				setAlternativeExporterIfCyclic(variable, importerForSideEffects, this);
+				if (this.info.moduleSideEffects) {
+					getOrCreate(
+						importerForSideEffects.sideEffectDependenciesByVariable,
+						variable,
+						getNewSet<Module>
+					).add(this);
+				}
 			}
 			return [variable];
 		}
@@ -613,12 +633,12 @@ export default class Module {
 				searchedNamesAndModules
 			})!;
 			if (importerForSideEffects) {
+				setAlternativeExporterIfCyclic(variable, importerForSideEffects, this);
 				getOrCreate(
 					importerForSideEffects.sideEffectDependenciesByVariable,
 					variable,
-					getNewSet
+					getNewSet<Module>
 				).add(this);
-				setAlternativeExporterIfCyclic(variable, importerForSideEffects, this);
 			}
 			return [variable];
 		}
@@ -709,11 +729,42 @@ export default class Module {
 		this.includeAllExports(false);
 	}
 
+	includeExportsByNames(names: readonly string[]): void {
+		if (!this.isExecuted) {
+			markModuleAndImpureDependenciesAsExecuted(this);
+			this.graph.needsTreeshakingPass = true;
+		}
+
+		let includeNamespaceMembers = false;
+
+		for (const name of names) {
+			const variable = this.getVariableForExportName(name)[0];
+			if (variable) {
+				variable.deoptimizePath(UNKNOWN_PATH);
+				if (!variable.included) {
+					this.includeVariable(variable);
+				}
+			}
+
+			if (!this.exports.has(name) && !this.reexportDescriptions.has(name)) {
+				includeNamespaceMembers = true;
+			}
+		}
+
+		if (includeNamespaceMembers) {
+			this.namespace.setMergedNamespaces(this.includeAndGetAdditionalMergedNamespaces());
+		}
+	}
+
 	isIncluded(): boolean | null {
 		// Modules where this.ast is missing have been loaded via this.load and are
 		// not yet fully processed, hence they cannot be included.
 		return (
-			this.ast && (this.ast.included || this.namespace.included || this.importedFromNotTreeshaken)
+			this.ast &&
+			(this.ast.included ||
+				this.namespace.included ||
+				this.importedFromNotTreeshaken ||
+				this.exportShimVariable.included)
 		);
 	}
 
@@ -732,13 +783,18 @@ export default class Module {
 		this.exportAllModules.push(...externalExportAllModules);
 	}
 
+	log(level: LogLevel, properties: RollupLog, pos: number): void {
+		this.addLocationToLogProps(properties, pos);
+		this.options.onLog(level, properties);
+	}
+
 	render(options: RenderOptions): { source: MagicString; usesTopLevelAwait: boolean } {
 		const source = this.magicString.clone();
 		this.ast!.render(source, options);
 		source.trim();
 		const { usesTopLevelAwait } = this.astContext;
 		if (usesTopLevelAwait && options.format !== 'es' && options.format !== 'system') {
-			return error(errorInvalidFormatForTopLevelAwait(this.id, options.format));
+			return error(logInvalidFormatForTopLevelAwait(this.id, options.format));
 		}
 		return { source, usesTopLevelAwait };
 	}
@@ -762,8 +818,18 @@ export default class Module {
 
 		this.info.code = code;
 		this.originalCode = originalCode;
-		this.originalSourcemap = originalSourcemap;
-		this.sourcemapChain = sourcemapChain;
+
+		// We need to call decodedSourcemap on the input in case they were hydrated from json in the cache and don't
+		// have the lazy evaluation cache configured. Right now this isn't enforced by the type system because the
+		// RollupCache stores `ExistingDecodedSourcemap` instead of `ExistingRawSourcemap`
+		this.originalSourcemap = decodedSourcemap(originalSourcemap);
+		this.sourcemapChain = sourcemapChain.map(mapOrMissing =>
+			mapOrMissing.missing ? mapOrMissing : decodedSourcemap(mapOrMissing)
+		);
+
+		// If coming from cache and this value is already fully decoded, we want to re-encode here to save memory.
+		resetSourcemapCache(this.originalSourcemap, this.sourcemapChain);
+
 		if (transformFiles) {
 			this.transformFiles = transformFiles;
 		}
@@ -804,6 +870,7 @@ export default class Module {
 			includeAllExports: () => this.includeAllExports(true),
 			includeDynamicImport: this.includeDynamicImport.bind(this),
 			includeVariableInModule: this.includeVariableInModule.bind(this),
+			log: this.log.bind(this),
 			magicString: this.magicString,
 			manualPureFunctions: this.graph.pureFunctions,
 			module: this,
@@ -812,8 +879,7 @@ export default class Module {
 			requestTreeshakingPass: () => (this.graph.needsTreeshakingPass = true),
 			traceExport: (name: string) => this.getVariableForExportName(name)[0],
 			traceVariable: this.traceVariable.bind(this),
-			usesTopLevelAwait: false,
-			warn: this.warn.bind(this)
+			usesTopLevelAwait: false
 		};
 
 		this.scope = new ModuleScope(this.graph.scope, this.astContext);
@@ -898,7 +964,7 @@ export default class Module {
 
 			if (!declaration) {
 				return this.error(
-					errorMissingExport(importDescription.name, this.id, otherModule.id),
+					logMissingExport(importDescription.name, this.id, otherModule.id),
 					importDescription.start
 				);
 			}
@@ -925,11 +991,6 @@ export default class Module {
 		}
 	}
 
-	warn(properties: RollupWarning, pos: number): void {
-		this.addLocationToLogProps(properties, pos);
-		this.options.onwarn(properties);
-	}
-
 	private addDynamicImport(node: ImportExpression) {
 		let argument: ExpressionNode | string = node.source;
 		if (argument instanceof TemplateLiteral) {
@@ -1049,7 +1110,10 @@ export default class Module {
 				({ column, line } = getOriginalLocation(this.sourcemapChain, { column, line }));
 				code = this.originalCode;
 			} catch (error_: any) {
-				this.options.onwarn(errorInvalidSourcemapForError(error_, this.id, column, line, pos));
+				this.options.onLog(
+					LOGLEVEL_WARN,
+					logInvalidSourcemapForError(error_, this.id, column, line, pos)
+				);
 			}
 			augmentCodeLocation(properties, { column, line }, code!, this.id);
 		}
@@ -1106,8 +1170,9 @@ export default class Module {
 		const existingAssertions = this.sourcesWithAssertions.get(source);
 		if (existingAssertions) {
 			if (doAssertionsDiffer(existingAssertions, parsedAssertions)) {
-				this.warn(
-					errorInconsistentImportAssertions(existingAssertions, parsedAssertions, source, this.id),
+				this.log(
+					LOGLEVEL_WARN,
+					logInconsistentImportAssertions(existingAssertions, parsedAssertions, source, this.id),
 					declaration.start
 				);
 			}
@@ -1155,8 +1220,9 @@ export default class Module {
 			if (foundDeclarationList.length === 1) {
 				return [usedDeclaration];
 			}
-			this.options.onwarn(
-				errorNamespaceConflict(
+			this.options.onLog(
+				LOGLEVEL_WARN,
+				logNamespaceConflict(
 					name,
 					this.id,
 					foundDeclarationList.map(([, module]) => module.id)
@@ -1169,8 +1235,9 @@ export default class Module {
 			const foundDeclarationList = [...foundExternalDeclarations];
 			const usedDeclaration = foundDeclarationList[0];
 			if (foundDeclarationList.length > 1) {
-				this.options.onwarn(
-					errorAmbiguousExternalNamespaces(
+				this.options.onLog(
+					LOGLEVEL_WARN,
+					logAmbiguousExternalNamespaces(
 						name,
 						this.id,
 						usedDeclaration.module.id,
@@ -1211,17 +1278,31 @@ export default class Module {
 				resolution: string | Module | ExternalModule | undefined;
 			}
 		).resolution;
+
 		if (resolution instanceof Module) {
 			resolution.includedDynamicImporters.push(this);
-			resolution.includeAllExports(true);
+
+			const importedNames = this.options.treeshake
+				? node.getDeterministicImportedNames()
+				: undefined;
+
+			if (importedNames) {
+				resolution.includeExportsByNames(importedNames);
+			} else {
+				resolution.includeAllExports(true);
+			}
 		}
 	}
 
 	private includeVariable(variable: Variable): void {
-		if (!variable.included) {
+		const variableModule = variable.module;
+		if (variable.included) {
+			if (variableModule instanceof Module && variableModule !== this) {
+				getAndExtendSideEffectModules(variable, this);
+			}
+		} else {
 			variable.include();
 			this.graph.needsTreeshakingPass = true;
-			const variableModule = variable.module;
 			if (variableModule instanceof Module) {
 				if (!variableModule.isExecuted) {
 					markModuleAndImpureDependenciesAsExecuted(variableModule);
@@ -1247,7 +1328,7 @@ export default class Module {
 	}
 
 	private shimMissingExport(name: string): void {
-		this.options.onwarn(errorShimmedExport(this.id, name));
+		this.options.onLog(LOGLEVEL_WARN, logShimmedExport(this.id, name));
 		this.exports.set(name, MISSING_EXPORT_SHIM_DESCRIPTION);
 	}
 
@@ -1255,7 +1336,7 @@ export default class Module {
 		try {
 			return this.graph.contextParse(this.info.code!);
 		} catch (error_: any) {
-			return this.error(errorParseError(error_, this.id), error_.pos);
+			return this.error(logParseError(error_, this.id), error_.pos);
 		}
 	}
 }
