@@ -17,20 +17,23 @@ import type {
 } from './rollup/types';
 import type { PluginDriver } from './utils/PluginDriver';
 import { EMPTY_OBJECT } from './utils/blank';
+import { readFile } from './utils/fs';
+import { LOGLEVEL_WARN } from './utils/logging';
 import {
 	error,
-	errorBadLoader,
-	errorEntryCannotBeExternal,
-	errorExternalSyntheticExports,
-	errorImplicitDependantCannotBeExternal,
-	errorInconsistentImportAssertions,
-	errorInternalIdCannotBeExternal,
-	errorUnresolvedEntry,
-	errorUnresolvedImplicitDependant,
-	errorUnresolvedImport,
-	errorUnresolvedImportTreatedAsExternal
-} from './utils/error';
-import { readFile } from './utils/fs';
+	logBadLoader,
+	logEntryCannotBeExternal,
+	logExternalModulesCannotBeIncludedInManualChunks,
+	logExternalModulesCannotBeTransformedToModules,
+	logExternalSyntheticExports,
+	logImplicitDependantCannotBeExternal,
+	logInconsistentImportAssertions,
+	logInternalIdCannotBeExternal,
+	logUnresolvedEntry,
+	logUnresolvedImplicitDependant,
+	logUnresolvedImport,
+	logUnresolvedImportTreatedAsExternal
+} from './utils/logs';
 import { doAssertionsDiffer, getAssertionsFromImportExpression } from './utils/parseAssertions';
 import { isAbsolute, isRelative, resolve } from './utils/path';
 import relativeId from './utils/relativeId';
@@ -94,9 +97,16 @@ export class ModuleLoader {
 			: () => true;
 	}
 
-	async addAdditionalModules(unresolvedModules: readonly string[]): Promise<Module[]> {
+	async addAdditionalModules(
+		unresolvedModules: readonly string[],
+		isAddForManualChunks: boolean
+	): Promise<Module[]> {
 		const result = this.extendLoadModulesPromise(
-			Promise.all(unresolvedModules.map(id => this.loadEntryModule(id, false, undefined, null)))
+			Promise.all(
+				unresolvedModules.map(id =>
+					this.loadEntryModule(id, false, undefined, null, isAddForManualChunks)
+				)
+			)
 		);
 		await this.awaitLoadModulesPromise();
 		return result;
@@ -274,7 +284,7 @@ export class ModuleLoader {
 				? { code: source }
 				: source != null && typeof source === 'object' && typeof source.code === 'string'
 				? source
-				: error(errorBadLoader(id));
+				: error(logBadLoader(id));
 		const cachedModule = this.graph.cachedModules.get(id);
 		if (
 			cachedModule &&
@@ -300,7 +310,7 @@ export class ModuleLoader {
 		} else {
 			module.updateOptions(sourceDescription);
 			module.setSource(
-				await transform(sourceDescription, module, this.pluginDriver, this.options.onwarn)
+				await transform(sourceDescription, module, this.pluginDriver, this.options.onLog)
 			);
 		}
 	}
@@ -366,19 +376,19 @@ export class ModuleLoader {
 		const existingModule = this.modulesById.get(id);
 		if (existingModule instanceof Module) {
 			if (importer && doAssertionsDiffer(assertions, existingModule.info.assertions)) {
-				this.options.onwarn(
-					errorInconsistentImportAssertions(
-						existingModule.info.assertions,
-						assertions,
-						id,
-						importer
-					)
+				this.options.onLog(
+					LOGLEVEL_WARN,
+					logInconsistentImportAssertions(existingModule.info.assertions, assertions, id, importer)
 				);
 			}
 			await this.handleExistingModule(existingModule, isEntry, isPreload);
 			return existingModule;
 		}
 
+		if (existingModule instanceof ExternalModule) {
+			return error(logExternalModulesCannotBeTransformedToModules(existingModule.id));
+		}
+
 		const module = new Module(
 			this.graph,
 			id,
@@ -450,10 +460,11 @@ export class ModuleLoader {
 				);
 				this.modulesById.set(id, externalModule);
 			} else if (!(externalModule instanceof ExternalModule)) {
-				return error(errorInternalIdCannotBeExternal(source, importer));
+				return error(logInternalIdCannotBeExternal(source, importer));
 			} else if (doAssertionsDiffer(externalModule.info.assertions, assertions)) {
-				this.options.onwarn(
-					errorInconsistentImportAssertions(
+				this.options.onLog(
+					LOGLEVEL_WARN,
+					logInconsistentImportAssertions(
 						externalModule.info.assertions,
 						assertions,
 						source,
@@ -618,9 +629,9 @@ export class ModuleLoader {
 	): ResolvedId {
 		if (resolvedId === null) {
 			if (isRelative(source)) {
-				return error(errorUnresolvedImport(source, importer));
+				return error(logUnresolvedImport(source, importer));
 			}
-			this.options.onwarn(errorUnresolvedImportTreatedAsExternal(source, importer));
+			this.options.onLog(LOGLEVEL_WARN, logUnresolvedImportTreatedAsExternal(source, importer));
 			return {
 				assertions,
 				external: true,
@@ -631,7 +642,7 @@ export class ModuleLoader {
 				syntheticNamedExports: false
 			};
 		} else if (resolvedId.external && resolvedId.syntheticNamedExports) {
-			this.options.onwarn(errorExternalSyntheticExports(source, importer));
+			this.options.onLog(LOGLEVEL_WARN, logExternalSyntheticExports(source, importer));
 		}
 		return resolvedId;
 	}
@@ -640,7 +651,8 @@ export class ModuleLoader {
 		unresolvedId: string,
 		isEntry: boolean,
 		importer: string | undefined,
-		implicitlyLoadedBefore: string | null
+		implicitlyLoadedBefore: string | null,
+		isLoadForManualChunks = false
 	): Promise<Module> {
 		const resolveIdResult = await resolveId(
 			unresolvedId,
@@ -656,18 +668,18 @@ export class ModuleLoader {
 		if (resolveIdResult == null) {
 			return error(
 				implicitlyLoadedBefore === null
-					? errorUnresolvedEntry(unresolvedId)
-					: errorUnresolvedImplicitDependant(unresolvedId, implicitlyLoadedBefore)
+					? logUnresolvedEntry(unresolvedId)
+					: logUnresolvedImplicitDependant(unresolvedId, implicitlyLoadedBefore)
 			);
 		}
-		if (
-			resolveIdResult === false ||
-			(typeof resolveIdResult === 'object' && resolveIdResult.external)
-		) {
+		const isExternalModules = typeof resolveIdResult === 'object' && resolveIdResult.external;
+		if (resolveIdResult === false || isExternalModules) {
 			return error(
 				implicitlyLoadedBefore === null
-					? errorEntryCannotBeExternal(unresolvedId)
-					: errorImplicitDependantCannotBeExternal(unresolvedId, implicitlyLoadedBefore)
+					? isExternalModules && isLoadForManualChunks
+						? logExternalModulesCannotBeIncludedInManualChunks(unresolvedId)
+						: logEntryCannotBeExternal(unresolvedId)
+					: logImplicitDependantCannotBeExternal(unresolvedId, implicitlyLoadedBefore)
 			);
 		}
 		return this.fetchModule(
@@ -710,8 +722,9 @@ export class ModuleLoader {
 			const existingResolution = module.resolvedIds[specifier];
 			if (existingResolution) {
 				if (doAssertionsDiffer(existingResolution.assertions, assertions)) {
-					this.options.onwarn(
-						errorInconsistentImportAssertions(
+					this.options.onLog(
+						LOGLEVEL_WARN,
+						logInconsistentImportAssertions(
 							existingResolution.assertions,
 							assertions,
 							specifier,
