@@ -11,12 +11,10 @@ interface ExecutionContextIgnore {
 	this: boolean;
 }
 
-export const BROKEN_FLOW_NONE = 0;
-export const BROKEN_FLOW_BREAK_CONTINUE = 1;
-export const BROKEN_FLOW_ERROR_RETURN_LABEL = 2;
-
 interface ControlFlowContext {
-	brokenFlow: number;
+	brokenFlow: boolean;
+	hasBreak: boolean;
+	hasContinue: boolean;
 	includedLabels: Set<string>;
 }
 
@@ -27,7 +25,7 @@ export interface InclusionContext extends ControlFlowContext {
 export interface HasEffectsContext extends ControlFlowContext {
 	accessed: PathTracker;
 	assigned: PathTracker;
-	brokenFlow: number;
+	brokenFlow: boolean;
 	called: DiscriminatedPathTracker;
 	ignore: ExecutionContextIgnore;
 	instantiated: DiscriminatedPathTracker;
@@ -36,7 +34,9 @@ export interface HasEffectsContext extends ControlFlowContext {
 
 export function createInclusionContext(): InclusionContext {
 	return {
-		brokenFlow: BROKEN_FLOW_NONE,
+		brokenFlow: false,
+		hasBreak: false,
+		hasContinue: false,
 		includedCallArguments: new Set(),
 		includedLabels: new Set()
 	};
@@ -46,8 +46,10 @@ export function createHasEffectsContext(): HasEffectsContext {
 	return {
 		accessed: new PathTracker(),
 		assigned: new PathTracker(),
-		brokenFlow: BROKEN_FLOW_NONE,
+		brokenFlow: false,
 		called: new DiscriminatedPathTracker(),
+		hasBreak: false,
+		hasContinue: false,
 		ignore: {
 			breaks: false,
 			continues: false,
