@@ -3,6 +3,9 @@ import type { GenericEsTreeNode } from './nodes/shared/Node';
 export const keys: {
 	[name: string]: string[];
 } = {
+	// TODO this should be removed once ImportExpression follows official ESTree
+	//  specs with "null" as default
+	ImportExpression: ['arguments'],
 	Literal: [],
 	Program: ['body']
 };
