@@ -1,19 +1,13 @@
 import type MagicString from 'magic-string';
-import type { NormalizedTreeshakingOptions } from '../../rollup/types';
 import { BLANK } from '../../utils/blank';
-import { errorCannotCallNamespace, errorEval } from '../../utils/error';
+import { LOGLEVEL_WARN } from '../../utils/logging';
+import { logCannotCallNamespace, logEval } from '../../utils/logs';
 import { renderCallArguments } from '../../utils/renderCallArguments';
 import { type NodeRenderOptions, type RenderOptions } from '../../utils/renderHelpers';
 import type { DeoptimizableEntity } from '../DeoptimizableEntity';
 import type { HasEffectsContext, InclusionContext } from '../ExecutionContext';
-import type { NodeInteractionWithThisArgument } from '../NodeInteractions';
 import { INTERACTION_CALLED } from '../NodeInteractions';
-import {
-	EMPTY_PATH,
-	type PathTracker,
-	SHARED_RECURSION_TRACKER,
-	UNKNOWN_PATH
-} from '../utils/PathTracker';
+import { EMPTY_PATH, type PathTracker, SHARED_RECURSION_TRACKER } from '../utils/PathTracker';
 import Identifier from './Identifier';
 import MemberExpression from './MemberExpression';
 import type * as NodeType from './NodeType';
@@ -21,8 +15,8 @@ import type SpreadElement from './SpreadElement';
 import type Super from './Super';
 import CallExpressionBase from './shared/CallExpressionBase';
 import { type ExpressionEntity, UNKNOWN_RETURN_EXPRESSION } from './shared/Expression';
-import { INCLUDE_PARAMETERS } from './shared/Node';
 import type { ChainElement, ExpressionNode, IncludeChildren } from './shared/Node';
+import { INCLUDE_PARAMETERS } from './shared/Node';
 
 export default class CallExpression
 	extends CallExpressionBase
@@ -39,19 +33,20 @@ export default class CallExpression
 			const variable = this.scope.findVariable(this.callee.name);
 
 			if (variable.isNamespace) {
-				this.context.warn(errorCannotCallNamespace(this.callee.name), this.start);
+				this.context.log(LOGLEVEL_WARN, logCannotCallNamespace(this.callee.name), this.start);
 			}
 
 			if (this.callee.name === 'eval') {
-				this.context.warn(errorEval(this.context.module.id), this.start);
+				this.context.log(LOGLEVEL_WARN, logEval(this.context.module.id), this.start);
 			}
 		}
 		this.interaction = {
-			args: this.arguments,
-			thisArg:
+			args: [
 				this.callee instanceof MemberExpression && !this.callee.variable
 					? this.callee.object
 					: null,
+				...this.arguments
+			],
 			type: INTERACTION_CALLED,
 			withNew: false
 		};
@@ -62,11 +57,9 @@ export default class CallExpression
 			for (const argument of this.arguments) {
 				if (argument.hasEffects(context)) return true;
 			}
-			if (
-				(this.context.options.treeshake as NormalizedTreeshakingOptions).annotations &&
-				this.annotations
-			)
+			if (this.annotationPure) {
 				return false;
+			}
 			return (
 				this.callee.hasEffects(context) ||
 				this.callee.hasEffectsOnInteractionAtPath(EMPTY_PATH, this.interaction, context)
@@ -116,17 +109,11 @@ export default class CallExpression
 
 	protected applyDeoptimizations(): void {
 		this.deoptimized = true;
-		if (this.interaction.thisArg) {
-			this.callee.deoptimizeThisOnInteractionAtPath(
-				this.interaction as NodeInteractionWithThisArgument,
-				EMPTY_PATH,
-				SHARED_RECURSION_TRACKER
-			);
-		}
-		for (const argument of this.arguments) {
-			// This will make sure all properties of parameters behave as "unknown"
-			argument.deoptimizePath(UNKNOWN_PATH);
-		}
+		this.callee.deoptimizeArgumentsOnInteractionAtPath(
+			this.interaction,
+			EMPTY_PATH,
+			SHARED_RECURSION_TRACKER
+		);
 		this.context.requestTreeshakingPass();
 	}
 
