@@ -1,9 +1,4 @@
-import {
-	BROKEN_FLOW_BREAK_CONTINUE,
-	BROKEN_FLOW_ERROR_RETURN_LABEL,
-	type HasEffectsContext,
-	type InclusionContext
-} from '../ExecutionContext';
+import { type HasEffectsContext, type InclusionContext } from '../ExecutionContext';
 import type Identifier from './Identifier';
 import type * as NodeType from './NodeType';
 import { StatementBase } from './shared/Node';
@@ -16,11 +11,11 @@ export default class ContinueStatement extends StatementBase {
 		if (this.label) {
 			if (!context.ignore.labels.has(this.label.name)) return true;
 			context.includedLabels.add(this.label.name);
-			context.brokenFlow = BROKEN_FLOW_ERROR_RETURN_LABEL;
 		} else {
 			if (!context.ignore.continues) return true;
-			context.brokenFlow = BROKEN_FLOW_BREAK_CONTINUE;
+			context.hasContinue = true;
 		}
+		context.brokenFlow = true;
 		return false;
 	}
 
@@ -29,7 +24,9 @@ export default class ContinueStatement extends StatementBase {
 		if (this.label) {
 			this.label.include();
 			context.includedLabels.add(this.label.name);
+		} else {
+			context.hasContinue = true;
 		}
-		context.brokenFlow = this.label ? BROKEN_FLOW_ERROR_RETURN_LABEL : BROKEN_FLOW_BREAK_CONTINUE;
+		context.brokenFlow = true;
 	}
 }
