@@ -6,6 +6,7 @@ import {
 	StatementBase,
 	type StatementNode
 } from './shared/Node';
+import { hasLoopBodyEffects, includeLoopBody } from './shared/loops';
 
 export default class DoWhileStatement extends StatementBase {
 	declare body: StatementNode;
@@ -14,22 +15,12 @@ export default class DoWhileStatement extends StatementBase {
 
 	hasEffects(context: HasEffectsContext): boolean {
 		if (this.test.hasEffects(context)) return true;
-		const { brokenFlow, ignore } = context;
-		const { breaks, continues } = ignore;
-		ignore.breaks = true;
-		ignore.continues = true;
-		if (this.body.hasEffects(context)) return true;
-		ignore.breaks = breaks;
-		ignore.continues = continues;
-		context.brokenFlow = brokenFlow;
-		return false;
+		return hasLoopBodyEffects(context, this.body);
 	}
 
 	include(context: InclusionContext, includeChildrenRecursively: IncludeChildren): void {
 		this.included = true;
 		this.test.include(context, includeChildrenRecursively);
-		const { brokenFlow } = context;
-		this.body.include(context, includeChildrenRecursively, { asSingleStatement: true });
-		context.brokenFlow = brokenFlow;
+		includeLoopBody(context, this.body, includeChildrenRecursively);
 	}
 }
