@@ -1,4 +1,4 @@
-import * as NodeType from './NodeType';
+import type * as NodeType from './NodeType';
 import { StatementBase } from './shared/Node';
 
 export default class EmptyStatement extends StatementBase {
