@@ -1,11 +1,13 @@
 import type MagicString from 'magic-string';
 import type { NodeRenderOptions, RenderOptions } from '../../utils/renderHelpers';
 import type Identifier from './Identifier';
+import type ImportAttribute from './ImportAttribute';
 import type Literal from './Literal';
 import type * as NodeType from './NodeType';
 import { NodeBase } from './shared/Node';
 
 export default class ExportAllDeclaration extends NodeBase {
+	declare assertions: ImportAttribute[];
 	declare exported: Identifier | null;
 	declare needsBoundaries: true;
 	declare source: Literal<string>;
