@@ -1,8 +1,9 @@
 import type MagicString from 'magic-string';
 import type { AstContext } from '../../Module';
 import type { NormalizedTreeshakingOptions } from '../../rollup/types';
-import { BLANK } from '../../utils/blank';
-import { errorIllegalImportReassignment, errorMissingExport } from '../../utils/error';
+import { BLANK, EMPTY_ARRAY } from '../../utils/blank';
+import { LOGLEVEL_WARN } from '../../utils/logging';
+import { logIllegalImportReassignment, logMissingExport } from '../../utils/logs';
 import type { NodeRenderOptions, RenderOptions } from '../../utils/renderHelpers';
 import type { DeoptimizableEntity } from '../DeoptimizableEntity';
 import type { HasEffectsContext, InclusionContext } from '../ExecutionContext';
@@ -10,8 +11,7 @@ import type {
 	NodeInteraction,
 	NodeInteractionAccessed,
 	NodeInteractionAssigned,
-	NodeInteractionCalled,
-	NodeInteractionWithThisArgument
+	NodeInteractionCalled
 } from '../NodeInteractions';
 import { INTERACTION_ACCESSED, INTERACTION_ASSIGNED } from '../NodeInteractions';
 import {
@@ -36,13 +36,14 @@ import type PrivateIdentifier from './PrivateIdentifier';
 import type SpreadElement from './SpreadElement';
 import type Super from './Super';
 import {
+	deoptimizeInteraction,
 	type ExpressionEntity,
 	type LiteralValueOrUnknown,
 	UNKNOWN_RETURN_EXPRESSION,
 	UnknownValue
 } from './shared/Expression';
-import { NodeBase } from './shared/Node';
 import type { ChainElement, ExpressionNode, IncludeChildren } from './shared/Node';
+import { NodeBase } from './shared/Node';
 
 // To avoid infinite recursions
 const MAX_PATH_DEPTH = 7;
@@ -101,8 +102,8 @@ export default class MemberExpression
 	declare propertyKey: ObjectPathKey | null;
 	declare type: NodeType.tMemberExpression;
 	variable: Variable | null = null;
-	protected declare assignmentInteraction: NodeInteractionAssigned & { thisArg: ExpressionEntity };
-	private declare accessInteraction: NodeInteractionAccessed & { thisArg: ExpressionEntity };
+	protected declare assignmentInteraction: NodeInteractionAssigned;
+	private declare accessInteraction: NodeInteractionAccessed;
 	private assignmentDeoptimized = false;
 	private bound = false;
 	private expressionsToBeDeoptimized: DeoptimizableEntity[] = [];
@@ -131,11 +132,31 @@ export default class MemberExpression
 		}
 	}
 
+	deoptimizeArgumentsOnInteractionAtPath(
+		interaction: NodeInteraction,
+		path: ObjectPath,
+		recursionTracker: PathTracker
+	): void {
+		if (this.variable) {
+			this.variable.deoptimizeArgumentsOnInteractionAtPath(interaction, path, recursionTracker);
+		} else if (!this.isUndefined) {
+			if (path.length < MAX_PATH_DEPTH) {
+				this.object.deoptimizeArgumentsOnInteractionAtPath(
+					interaction,
+					[this.getPropertyKey(), ...path],
+					recursionTracker
+				);
+			} else {
+				deoptimizeInteraction(interaction);
+			}
+		}
+	}
+
 	deoptimizeCache(): void {
-		const expressionsToBeDeoptimized = this.expressionsToBeDeoptimized;
-		this.expressionsToBeDeoptimized = [];
+		const { expressionsToBeDeoptimized, object } = this;
+		this.expressionsToBeDeoptimized = EMPTY_ARRAY as unknown as DeoptimizableEntity[];
 		this.propertyKey = UnknownKey;
-		this.object.deoptimizePath(UNKNOWN_PATH);
+		object.deoptimizePath(UNKNOWN_PATH);
 		for (const expression of expressionsToBeDeoptimized) {
 			expression.deoptimizeCache();
 		}
@@ -154,26 +175,6 @@ export default class MemberExpression
 		}
 	}
 
-	deoptimizeThisOnInteractionAtPath(
-		interaction: NodeInteractionWithThisArgument,
-		path: ObjectPath,
-		recursionTracker: PathTracker
-	): void {
-		if (this.variable) {
-			this.variable.deoptimizeThisOnInteractionAtPath(interaction, path, recursionTracker);
-		} else if (!this.isUndefined) {
-			if (path.length < MAX_PATH_DEPTH) {
-				this.object.deoptimizeThisOnInteractionAtPath(
-					interaction,
-					[this.getPropertyKey(), ...path],
-					recursionTracker
-				);
-			} else {
-				interaction.thisArg.deoptimizePath(UNKNOWN_PATH);
-			}
-		}
-	}
-
 	getLiteralValueAtPath(
 		path: ObjectPath,
 		recursionTracker: PathTracker,
@@ -185,8 +186,8 @@ export default class MemberExpression
 		if (this.isUndefined) {
 			return undefined;
 		}
-		this.expressionsToBeDeoptimized.push(origin);
-		if (path.length < MAX_PATH_DEPTH) {
+		if (this.propertyKey !== UnknownKey && path.length < MAX_PATH_DEPTH) {
+			this.expressionsToBeDeoptimized.push(origin);
 			return this.object.getLiteralValueAtPath(
 				[this.getPropertyKey(), ...path],
 				recursionTracker,
@@ -213,8 +214,8 @@ export default class MemberExpression
 		if (this.isUndefined) {
 			return [UNDEFINED_EXPRESSION, false];
 		}
-		this.expressionsToBeDeoptimized.push(origin);
-		if (path.length < MAX_PATH_DEPTH) {
+		if (this.propertyKey !== UnknownKey && path.length < MAX_PATH_DEPTH) {
+			this.expressionsToBeDeoptimized.push(origin);
 			return this.object.getReturnExpressionWhenCalledAtPath(
 				[this.getPropertyKey(), ...path],
 				interaction,
@@ -297,7 +298,7 @@ export default class MemberExpression
 
 	initialise(): void {
 		this.propertyKey = getResolvablePropertyKey(this);
-		this.accessInteraction = { thisArg: this.object, type: INTERACTION_ACCESSED };
+		this.accessInteraction = { args: [this.object], type: INTERACTION_ACCESSED };
 	}
 
 	isSkippedAsOptional(origin: DeoptimizableEntity): boolean {
@@ -340,8 +341,7 @@ export default class MemberExpression
 
 	setAssignedValue(value: ExpressionEntity) {
 		this.assignmentInteraction = {
-			args: [value],
-			thisArg: this.object,
+			args: [this.object, value],
 			type: INTERACTION_ASSIGNED
 		};
 	}
@@ -357,7 +357,7 @@ export default class MemberExpression
 			!(this.variable || this.isUndefined)
 		) {
 			const propertyKey = this.getPropertyKey();
-			this.object.deoptimizeThisOnInteractionAtPath(
+			this.object.deoptimizeArgumentsOnInteractionAtPath(
 				this.accessInteraction,
 				[propertyKey],
 				SHARED_RECURSION_TRACKER
@@ -376,7 +376,7 @@ export default class MemberExpression
 			propertyReadSideEffects &&
 			!(this.variable || this.isUndefined)
 		) {
-			this.object.deoptimizeThisOnInteractionAtPath(
+			this.object.deoptimizeArgumentsOnInteractionAtPath(
 				this.assignmentInteraction,
 				[this.getPropertyKey()],
 				SHARED_RECURSION_TRACKER
@@ -392,8 +392,9 @@ export default class MemberExpression
 				if (this.variable) {
 					this.context.includeVariableInModule(this.variable);
 				}
-				this.context.warn(
-					errorIllegalImportReassignment(this.object.name, this.context.module.id),
+				this.context.log(
+					LOGLEVEL_WARN,
+					logIllegalImportReassignment(this.object.name, this.context.module.id),
 					this.start
 				);
 			}
@@ -456,7 +457,11 @@ function resolveNamespaceVariables(
 	if (!variable) {
 		if (path.length === 1) {
 			const fileName = (baseVariable as NamespaceVariable).context.fileName;
-			astContext.warn(errorMissingExport(exportName, astContext.module.id, fileName), path[0].pos);
+			astContext.log(
+				LOGLEVEL_WARN,
+				logMissingExport(exportName, astContext.module.id, fileName),
+				path[0].pos
+			);
 			return 'undefined';
 		}
 		return null;
