@@ -3,6 +3,7 @@ import type { InternalModuleFormat } from '../../rollup/types';
 import type { PluginDriver } from '../../utils/PluginDriver';
 import { escapeId } from '../../utils/escapeId';
 import type { GenerateCodeSnippets } from '../../utils/generateCodeSnippets';
+import { DOCUMENT_CURRENT_SCRIPT } from '../../utils/interopHelpers';
 import { dirname, normalize, relative } from '../../utils/path';
 import type { RenderOptions } from '../../utils/renderHelpers';
 import type { NodeInteraction } from '../NodeInteractions';
@@ -62,11 +63,10 @@ export default class MetaProperty extends NodeBase {
 		}
 	}
 
-	render(code: MagicString, { format, pluginDriver, snippets }: RenderOptions): void {
+	render(code: MagicString, renderOptions: RenderOptions): void {
+		const { format, pluginDriver, snippets } = renderOptions;
 		const {
-			context: {
-				module: { id: moduleId }
-			},
+			context: { module },
 			meta: { name },
 			metaProperty,
 			parent,
@@ -75,6 +75,8 @@ export default class MetaProperty extends NodeBase {
 			start,
 			end
 		} = this;
+		const { id: moduleId } = module;
+
 		if (name !== IMPORT) return;
 		const chunkId = preliminaryChunkId!;
 
@@ -95,11 +97,15 @@ export default class MetaProperty extends NodeBase {
 			return;
 		}
 
-		const replacement =
-			pluginDriver.hookFirstSync('resolveImportMeta', [
-				metaProperty,
-				{ chunkId, format, moduleId }
-			]) || importMetaMechanisms[format]?.(metaProperty, { chunkId, snippets });
+		let replacement = pluginDriver.hookFirstSync('resolveImportMeta', [
+			metaProperty,
+			{ chunkId, format, moduleId }
+		]);
+		if (!replacement) {
+			replacement = importMetaMechanisms[format]?.(metaProperty, { chunkId, snippets });
+			renderOptions.accessedDocumentCurrentScript ||=
+				formatsMaybeAccessDocumentCurrentScript.includes(format) && replacement !== 'undefined';
+		}
 		if (typeof replacement === 'string') {
 			if (parent instanceof MemberExpression) {
 				code.overwrite(parent.start, parent.end, replacement, { contentOnly: true });
@@ -124,13 +130,15 @@ export default class MetaProperty extends NodeBase {
 	}
 }
 
+export const formatsMaybeAccessDocumentCurrentScript = ['cjs', 'iife', 'umd'];
+
 const accessedMetaUrlGlobals = {
 	amd: ['document', 'module', 'URL'],
-	cjs: ['document', 'require', 'URL'],
+	cjs: ['document', 'require', 'URL', DOCUMENT_CURRENT_SCRIPT],
 	es: [],
-	iife: ['document', 'URL'],
+	iife: ['document', 'URL', DOCUMENT_CURRENT_SCRIPT],
 	system: ['module'],
-	umd: ['document', 'require', 'URL']
+	umd: ['document', 'require', 'URL', DOCUMENT_CURRENT_SCRIPT]
 };
 
 const accessedFileUrlGlobals = {
@@ -148,7 +156,7 @@ const getRelativeUrlFromDocument = (relativePath: string, umd = false) =>
 	getResolveUrl(
 		`'${escapeId(relativePath)}', ${
 			umd ? `typeof document === 'undefined' ? location.href : ` : ''
-		}document.currentScript && document.currentScript.src || document.baseURI`
+		}document.currentScript && document.currentScript.tagName.toUpperCase() === 'SCRIPT' && document.currentScript.src || document.baseURI`
 	);
 
 const getGenericImportMetaMechanism =
@@ -162,10 +170,15 @@ const getGenericImportMetaMechanism =
 			: 'undefined';
 	};
 
+const getFileUrlFromFullPath = (path: string) => `require('u' + 'rl').pathToFileURL(${path}).href`;
+
+const getFileUrlFromRelativePath = (path: string) =>
+	getFileUrlFromFullPath(`__dirname + '/${path}'`);
+
 const getUrlFromDocument = (chunkId: string, umd = false) =>
 	`${
 		umd ? `typeof document === 'undefined' ? location.href : ` : ''
-	}(document.currentScript && document.currentScript.src || new URL('${escapeId(
+	}(${DOCUMENT_CURRENT_SCRIPT} && ${DOCUMENT_CURRENT_SCRIPT}.tagName.toUpperCase() === 'SCRIPT' && ${DOCUMENT_CURRENT_SCRIPT}.src || new URL('${escapeId(
 		chunkId
 	)}', document.baseURI).href)`;
 
@@ -175,17 +188,15 @@ const relativeUrlMechanisms: Record<InternalModuleFormat, (relativePath: string)
 		return getResolveUrl(`require.toUrl('${relativePath}'), document.baseURI`);
 	},
 	cjs: relativePath =>
-		`(typeof document === 'undefined' ? ${getResolveUrl(
-			`'file:' + __dirname + '/${relativePath}'`,
-			`(require('u' + 'rl').URL)`
+		`(typeof document === 'undefined' ? ${getFileUrlFromRelativePath(
+			relativePath
 		)} : ${getRelativeUrlFromDocument(relativePath)})`,
 	es: relativePath => getResolveUrl(`'${relativePath}', import.meta.url`),
 	iife: relativePath => getRelativeUrlFromDocument(relativePath),
 	system: relativePath => getResolveUrl(`'${relativePath}', module.meta.url`),
 	umd: relativePath =>
-		`(typeof document === 'undefined' && typeof location === 'undefined' ? ${getResolveUrl(
-			`'file:' + __dirname + '/${relativePath}'`,
-			`(require('u' + 'rl').URL)`
+		`(typeof document === 'undefined' && typeof location === 'undefined' ? ${getFileUrlFromRelativePath(
+			relativePath
 		)} : ${getRelativeUrlFromDocument(relativePath, true)})`
 };
 
@@ -196,9 +207,8 @@ const importMetaMechanisms: Record<
 	amd: getGenericImportMetaMechanism(() => getResolveUrl(`module.uri, document.baseURI`)),
 	cjs: getGenericImportMetaMechanism(
 		chunkId =>
-			`(typeof document === 'undefined' ? ${getResolveUrl(
-				`'file:' + __filename`,
-				`(require('u' + 'rl').URL)`
+			`(typeof document === 'undefined' ? ${getFileUrlFromFullPath(
+				'__filename'
 			)} : ${getUrlFromDocument(chunkId)})`
 	),
 	iife: getGenericImportMetaMechanism(chunkId => getUrlFromDocument(chunkId)),
@@ -206,9 +216,8 @@ const importMetaMechanisms: Record<
 		property === null ? `module.meta` : `module.meta${getPropertyAccess(property)}`,
 	umd: getGenericImportMetaMechanism(
 		chunkId =>
-			`(typeof document === 'undefined' && typeof location === 'undefined' ? ${getResolveUrl(
-				`'file:' + __filename`,
-				`(require('u' + 'rl').URL)`
+			`(typeof document === 'undefined' && typeof location === 'undefined' ? ${getFileUrlFromFullPath(
+				'__filename'
 			)} : ${getUrlFromDocument(chunkId, true)})`
 	)
 };
