@@ -1,6 +1,6 @@
 import type MagicString from 'magic-string';
 import type { RenderOptions } from '../../utils/renderHelpers';
-import { BROKEN_FLOW_ERROR_RETURN_LABEL, type InclusionContext } from '../ExecutionContext';
+import { type InclusionContext } from '../ExecutionContext';
 import type * as NodeType from './NodeType';
 import { type ExpressionNode, type IncludeChildren, StatementBase } from './shared/Node';
 
@@ -15,7 +15,7 @@ export default class ThrowStatement extends StatementBase {
 	include(context: InclusionContext, includeChildrenRecursively: IncludeChildren): void {
 		this.included = true;
 		this.argument.include(context, includeChildrenRecursively);
-		context.brokenFlow = BROKEN_FLOW_ERROR_RETURN_LABEL;
+		context.brokenFlow = true;
 	}
 
 	render(code: MagicString, options: RenderOptions): void {
