@@ -2,7 +2,9 @@ import type * as acorn from 'acorn';
 import { locate, type Location } from 'locate-character';
 import type MagicString from 'magic-string';
 import type { AstContext } from '../../../Module';
-import { ANNOTATION_KEY, INVALID_COMMENT_KEY } from '../../../utils/pureComments';
+import type { NormalizedTreeshakingOptions } from '../../../rollup/types';
+import type { RollupAnnotation } from '../../../utils/commentAnnotations';
+import { ANNOTATION_KEY, INVALID_COMMENT_KEY } from '../../../utils/commentAnnotations';
 import type { NodeRenderOptions, RenderOptions } from '../../../utils/renderHelpers';
 import type { DeoptimizableEntity } from '../../DeoptimizableEntity';
 import type { Entity } from '../../Entity';
@@ -65,7 +67,7 @@ export interface Node extends Entity {
 	/**
 	 * Special version of hasEffects for assignment left-hand sides which ensures
 	 * that accessor effects are checked as well. This is necessary to do from the
-	 * child so that member expressions can use the correct thisArg value.
+	 * child so that member expressions can use the correct this value.
 	 * setAssignedValue needs to be called during initialise to use this.
 	 */
 	hasEffectsAsAssignmentTarget(context: HasEffectsContext, checkAccess: boolean): boolean;
@@ -84,7 +86,7 @@ export interface Node extends Entity {
 	/**
 	 * Special version of include for assignment left-hand sides which ensures
 	 * that accessors are handled correctly. This is necessary to do from the
-	 * child so that member expressions can use the correct thisArg value.
+	 * child so that member expressions can use the correct this value.
 	 * setAssignedValue needs to be called during initialise to use this.
 	 */
 	includeAsAssignmentTarget(
@@ -124,7 +126,12 @@ export interface ChainElement extends ExpressionNode {
 }
 
 export class NodeBase extends ExpressionEntity implements ExpressionNode {
-	declare annotations?: acorn.Comment[];
+	/** Marked with #__NO_SIDE_EFFECTS__ annotation */
+	declare annotationNoSideEffects?: boolean;
+	/** Marked with #__PURE__ annotation */
+	declare annotationPure?: boolean;
+	declare annotations?: RollupAnnotation[];
+
 	context: AstContext;
 	declare end: number;
 	esTreeNode: acorn.Node | null;
@@ -171,8 +178,8 @@ export class NodeBase extends ExpressionEntity implements ExpressionNode {
 	): void {}
 
 	/**
-	 * Override this to bind assignments to variables and do any initialisations that
-	 * require the scopes to be populated with variables.
+	 * Override this to bind assignments to variables and do any initialisations
+	 * that require the scopes to be populated with variables.
 	 */
 	bind(): void {
 		for (const key of this.keys) {
@@ -188,7 +195,8 @@ export class NodeBase extends ExpressionEntity implements ExpressionNode {
 	}
 
 	/**
-	 * Override if this node should receive a different scope than the parent scope.
+	 * Override if this node should receive a different scope than the parent
+	 * scope.
 	 */
 	createScope(parentScope: ChildScope): void {
 		this.scope = parentScope;
@@ -244,7 +252,8 @@ export class NodeBase extends ExpressionEntity implements ExpressionNode {
 	}
 
 	/**
-	 * Override to perform special initialisation steps after the scope is initialised
+	 * Override to perform special initialisation steps after the scope is
+	 * initialised
 	 */
 	initialise(): void {}
 
@@ -260,7 +269,14 @@ export class NodeBase extends ExpressionEntity implements ExpressionNode {
 			if (this.hasOwnProperty(key)) continue;
 			if (key.charCodeAt(0) === 95 /* _ */) {
 				if (key === ANNOTATION_KEY) {
-					this.annotations = value;
+					const annotations = value as RollupAnnotation[];
+					this.annotations = annotations;
+					if ((this.context.options.treeshake as NormalizedTreeshakingOptions).annotations) {
+						this.annotationNoSideEffects = annotations.some(
+							comment => comment.annotationType === 'noSideEffects'
+						);
+						this.annotationPure = annotations.some(comment => comment.annotationType === 'pure');
+					}
 				} else if (key === INVALID_COMMENT_KEY) {
 					for (const { start, end } of value as acorn.Comment[])
 						this.context.magicString.remove(start, end);
@@ -307,7 +323,7 @@ export class NodeBase extends ExpressionEntity implements ExpressionNode {
 	}
 
 	setAssignedValue(value: ExpressionEntity): void {
-		this.assignmentInteraction = { args: [value], thisArg: null, type: INTERACTION_ASSIGNED };
+		this.assignmentInteraction = { args: [null, value], type: INTERACTION_ASSIGNED };
 	}
 
 	shouldBeIncluded(context: InclusionContext): boolean {
