@@ -1,17 +1,16 @@
-import type Module from '../../Module';
-import type { AstContext } from '../../Module';
+import type { AstContext, default as Module } from '../../Module';
 import { getToStringTagValue, MERGE_NAMESPACES_VARIABLE } from '../../utils/interopHelpers';
 import type { RenderOptions } from '../../utils/renderHelpers';
 import { getSystemExportStatement } from '../../utils/systemJsRendering';
 import type { HasEffectsContext } from '../ExecutionContext';
+import type { NodeInteraction } from '../NodeInteractions';
 import { INTERACTION_ASSIGNED, INTERACTION_CALLED } from '../NodeInteractions';
-import type { NodeInteraction, NodeInteractionWithThisArgument } from '../NodeInteractions';
 import type Identifier from '../nodes/Identifier';
 import type { LiteralValueOrUnknown } from '../nodes/shared/Expression';
-import { UnknownValue } from '../nodes/shared/Expression';
+import { deoptimizeInteraction, UnknownValue } from '../nodes/shared/Expression';
 import type ChildScope from '../scopes/ChildScope';
 import type { ObjectPath, PathTracker } from '../utils/PathTracker';
-import { SymbolToStringTag, UNKNOWN_PATH } from '../utils/PathTracker';
+import { SymbolToStringTag } from '../utils/PathTracker';
 import Variable from './Variable';
 
 export default class NamespaceVariable extends Variable {
@@ -35,30 +34,30 @@ export default class NamespaceVariable extends Variable {
 		this.name = identifier.name;
 	}
 
-	deoptimizePath(path: ObjectPath) {
-		if (path.length > 1) {
-			const key = path[0];
-			if (typeof key === 'string') {
-				this.getMemberVariables()[key]?.deoptimizePath(path.slice(1));
-			}
-		}
-	}
-
-	deoptimizeThisOnInteractionAtPath(
-		interaction: NodeInteractionWithThisArgument,
+	deoptimizeArgumentsOnInteractionAtPath(
+		interaction: NodeInteraction,
 		path: ObjectPath,
 		recursionTracker: PathTracker
 	) {
 		if (path.length > 1 || (path.length === 1 && interaction.type === INTERACTION_CALLED)) {
 			const key = path[0];
 			if (typeof key === 'string') {
-				this.getMemberVariables()[key]?.deoptimizeThisOnInteractionAtPath(
+				this.getMemberVariables()[key]?.deoptimizeArgumentsOnInteractionAtPath(
 					interaction,
 					path.slice(1),
 					recursionTracker
 				);
 			} else {
-				interaction.thisArg.deoptimizePath(UNKNOWN_PATH);
+				deoptimizeInteraction(interaction);
+			}
+		}
+	}
+
+	deoptimizePath(path: ObjectPath) {
+		if (path.length > 1) {
+			const key = path[0];
+			if (typeof key === 'string') {
+				this.getMemberVariables()[key]?.deoptimizePath(path.slice(1));
 			}
 		}
 	}
@@ -134,18 +133,18 @@ export default class NamespaceVariable extends Variable {
 			snippets: { _, cnst, getObject, getPropertyAccess, n, s }
 		} = options;
 		const memberVariables = this.getMemberVariables();
-		const members: [key: string | null, value: string][] = Object.entries(memberVariables).map(
-			([name, original]) => {
-				if (this.referencedEarly || original.isReassigned) {
+		const members: [key: string | null, value: string][] = Object.entries(memberVariables)
+			.filter(([_, variable]) => variable.included)
+			.map(([name, variable]) => {
+				if (this.referencedEarly || variable.isReassigned || variable === this) {
 					return [
 						null,
-						`get ${name}${_}()${_}{${_}return ${original.getName(getPropertyAccess)}${s}${_}}`
+						`get ${name}${_}()${_}{${_}return ${variable.getName(getPropertyAccess)}${s}${_}}`
 					];
 				}
 
-				return [name, original.getName(getPropertyAccess)];
-			}
-		);
+				return [name, variable.getName(getPropertyAccess)];
+			});
 		members.unshift([null, `__proto__:${_}null`]);
 
 		let output = getObject(members, { lineBreakIndent: { base: '', t } });
