@@ -1,16 +1,16 @@
-import Variable from '../ast/variables/Variable';
+import type Variable from '../ast/variables/Variable';
+import RESERVED_NAMES from './RESERVED_NAMES';
 import { toBase64 } from './base64';
-import { RESERVED_NAMES } from './reservedNames';
 
 export function assignExportsToMangledNames(
-	exports: Set<Variable>,
-	exportsByName: Record<string, Variable>,
+	exports: ReadonlySet<Variable>,
+	exportsByName: Map<string, Variable>,
 	exportNamesByVariable: Map<Variable, string[]>
 ): void {
 	let nameIndex = 0;
 	for (const variable of exports) {
-		let exportName = variable.name[0];
-		if (exportsByName[exportName]) {
+		let [exportName] = variable.name;
+		if (exportsByName.has(exportName)) {
 			do {
 				exportName = toBase64(++nameIndex);
 				// skip past leading number identifiers
@@ -18,25 +18,25 @@ export function assignExportsToMangledNames(
 					nameIndex += 9 * 64 ** (exportName.length - 1);
 					exportName = toBase64(nameIndex);
 				}
-			} while (RESERVED_NAMES.has(exportName) || exportsByName[exportName]);
+			} while (RESERVED_NAMES.has(exportName) || exportsByName.has(exportName));
 		}
-		exportsByName[exportName] = variable;
+		exportsByName.set(exportName, variable);
 		exportNamesByVariable.set(variable, [exportName]);
 	}
 }
 
 export function assignExportsToNames(
-	exports: Set<Variable>,
-	exportsByName: Record<string, Variable>,
+	exports: ReadonlySet<Variable>,
+	exportsByName: Map<string, Variable>,
 	exportNamesByVariable: Map<Variable, string[]>
 ): void {
 	for (const variable of exports) {
 		let nameIndex = 0;
 		let exportName = variable.name;
-		while (exportsByName[exportName]) {
+		while (exportsByName.has(exportName)) {
 			exportName = variable.name + '$' + ++nameIndex;
 		}
-		exportsByName[exportName] = variable;
+		exportsByName.set(exportName, variable);
 		exportNamesByVariable.set(variable, [exportName]);
 	}
 }
