@@ -6,20 +6,17 @@ import type {
 	OutputOptions,
 	SourcemapPathTransformOption
 } from '../../rollup/types';
-import {
-	error,
-	errorInvalidExportOptionValue,
-	errorInvalidOption,
-	warnDeprecation
-} from '../error';
+import { LOGLEVEL_WARN } from '../logging';
+import { error, logInvalidExportOptionValue, logInvalidOption, warnDeprecation } from '../logs';
 import { resolve } from '../path';
 import { sanitizeFileName as defaultSanitizeFileName } from '../sanitizeFileName';
-import { isValidUrl } from '../url';
+import { addTrailingSlashIfMissed, isValidUrl } from '../url';
 import {
 	URL_OUTPUT_AMD_BASEPATH,
 	URL_OUTPUT_AMD_ID,
 	URL_OUTPUT_DIR,
 	URL_OUTPUT_DYNAMICIMPORTFUNCTION,
+	URL_OUTPUT_EXPERIMENTALDEEPCHUNKOPTIMIZATION,
 	URL_OUTPUT_FORMAT,
 	URL_OUTPUT_GENERATEDCODE,
 	URL_OUTPUT_GENERATEDCODE_CONSTBINDINGS,
@@ -66,9 +63,11 @@ export async function normalizeOutputOptions(
 		dynamicImportInCjs: config.dynamicImportInCjs ?? true,
 		entryFileNames: getEntryFileNames(config, unsetOptions),
 		esModule: config.esModule ?? 'if-default-prop',
-		experimentalDeepDynamicChunkOptimization:
-			config.experimentalDeepDynamicChunkOptimization || false,
-		experimentalMinChunkSize: config.experimentalMinChunkSize || 0,
+		experimentalDeepDynamicChunkOptimization: getExperimentalDeepDynamicChunkOptimization(
+			config,
+			inputOptions
+		),
+		experimentalMinChunkSize: config.experimentalMinChunkSize ?? 1,
 		exports: getExports(config, unsetOptions),
 		extend: config.extend || false,
 		externalImportAssertions: config.externalImportAssertions ?? true,
@@ -105,6 +104,13 @@ export async function normalizeOutputOptions(
 		sourcemapBaseUrl: getSourcemapBaseUrl(config),
 		sourcemapExcludeSources: config.sourcemapExcludeSources || false,
 		sourcemapFile: config.sourcemapFile,
+		sourcemapFileNames: getSourcemapFileNames(config, unsetOptions),
+		sourcemapIgnoreList:
+			typeof config.sourcemapIgnoreList === 'function'
+				? config.sourcemapIgnoreList
+				: config.sourcemapIgnoreList === false
+				? () => false
+				: relativeSourcePath => relativeSourcePath.includes('node_modules'),
 		sourcemapPathTransform: config.sourcemapPathTransform as
 			| SourcemapPathTransformOption
 			| undefined,
@@ -113,7 +119,7 @@ export async function normalizeOutputOptions(
 		validate: config.validate || false
 	};
 
-	warnUnknownOptions(config, Object.keys(outputOptions), 'output options', inputOptions.onwarn);
+	warnUnknownOptions(config, Object.keys(outputOptions), 'output options', inputOptions.onLog);
 	return { options: outputOptions, unsetOptions };
 }
 
@@ -126,7 +132,7 @@ const getFile = (
 	if (typeof file === 'string') {
 		if (preserveModules) {
 			return error(
-				errorInvalidOption(
+				logInvalidOption(
 					'output.file',
 					URL_OUTPUT_DIR,
 					'you must set "output.dir" instead of "output.file" when using the "output.preserveModules" option'
@@ -135,7 +141,7 @@ const getFile = (
 		}
 		if (!Array.isArray(inputOptions.input))
 			return error(
-				errorInvalidOption(
+				logInvalidOption(
 					'output.file',
 					URL_OUTPUT_DIR,
 					'you must set "output.dir" instead of "output.file" when providing named inputs'
@@ -169,7 +175,7 @@ const getFormat = (config: OutputOptions): NormalizedOutputOptions['format'] =>
 		}
 		default: {
 			return error(
-				errorInvalidOption(
+				logInvalidOption(
 					'output.format',
 					URL_OUTPUT_FORMAT,
 					`Valid values are "amd", "cjs", "system", "es", "iife" or "umd"`,
@@ -189,7 +195,7 @@ const getInlineDynamicImports = (
 	const { input } = inputOptions;
 	if (inlineDynamicImports && (Array.isArray(input) ? input : Object.keys(input)).length > 1) {
 		return error(
-			errorInvalidOption(
+			logInvalidOption(
 				'output.inlineDynamicImports',
 				URL_OUTPUT_INLINEDYNAMICIMPORTS,
 				'multiple inputs are not supported when "output.inlineDynamicImports" is true'
@@ -208,7 +214,7 @@ const getPreserveModules = (
 	if (preserveModules) {
 		if (inlineDynamicImports) {
 			return error(
-				errorInvalidOption(
+				logInvalidOption(
 					'output.inlineDynamicImports',
 					URL_OUTPUT_INLINEDYNAMICIMPORTS,
 					`this option is not supported for "output.preserveModules"`
@@ -217,7 +223,7 @@ const getPreserveModules = (
 		}
 		if (inputOptions.preserveEntrySignatures === false) {
 			return error(
-				errorInvalidOption(
+				logInvalidOption(
 					'preserveEntrySignatures',
 					URL_PRESERVEENTRYSIGNATURES,
 					'setting this option to false is not supported for "output.preserveModules"'
@@ -271,7 +277,7 @@ const getAmd = (config: OutputOptions): NormalizedOutputOptions['amd'] => {
 
 	if ((mergedOption.autoId || mergedOption.basePath) && mergedOption.id) {
 		return error(
-			errorInvalidOption(
+			logInvalidOption(
 				'output.amd.id',
 				URL_OUTPUT_AMD_ID,
 				'this option cannot be used together with "output.amd.autoId"/"output.amd.basePath"'
@@ -280,7 +286,7 @@ const getAmd = (config: OutputOptions): NormalizedOutputOptions['amd'] => {
 	}
 	if (mergedOption.basePath && !mergedOption.autoId) {
 		return error(
-			errorInvalidOption(
+			logInvalidOption(
 				'output.amd.basePath',
 				URL_OUTPUT_AMD_BASEPATH,
 				'this option only works with "output.amd.autoId"'
@@ -322,7 +328,7 @@ const getDir = (
 	const { dir } = config;
 	if (typeof dir === 'string' && typeof file === 'string') {
 		return error(
-			errorInvalidOption(
+			logInvalidOption(
 				'output.dir',
 				URL_OUTPUT_DIR,
 				'you must set either "output.file" for a single-file build or "output.dir" when generating multiple chunks'
@@ -346,8 +352,9 @@ const getDynamicImportFunction = (
 			inputOptions
 		);
 		if (format !== 'es') {
-			inputOptions.onwarn(
-				errorInvalidOption(
+			inputOptions.onLog(
+				LOGLEVEL_WARN,
+				logInvalidOption(
 					'output.dynamicImportFunction',
 					URL_OUTPUT_DYNAMICIMPORTFUNCTION,
 					'this option is ignored for formats other than "es"'
@@ -369,6 +376,23 @@ const getEntryFileNames = (
 	return configEntryFileNames ?? '[name].js';
 };
 
+function getExperimentalDeepDynamicChunkOptimization(
+	config: OutputOptions,
+	inputOptions: NormalizedInputOptions
+) {
+	const configExperimentalDeepDynamicChunkOptimization =
+		config.experimentalDeepDynamicChunkOptimization;
+	if (configExperimentalDeepDynamicChunkOptimization != null) {
+		warnDeprecation(
+			`The "output.experimentalDeepDynamicChunkOptimization" option is deprecated as Rollup always runs the full chunking algorithm now. The option should be removed.`,
+			URL_OUTPUT_EXPERIMENTALDEEPCHUNKOPTIMIZATION,
+			true,
+			inputOptions
+		);
+	}
+	return configExperimentalDeepDynamicChunkOptimization || false;
+}
+
 function getExports(
 	config: OutputOptions,
 	unsetOptions: Set<string>
@@ -377,7 +401,7 @@ function getExports(
 	if (configExports == null) {
 		unsetOptions.add('exports');
 	} else if (!['default', 'named', 'none', 'auto'].includes(configExports)) {
-		return error(errorInvalidExportOptionValue(configExports));
+		return error(logInvalidExportOptionValue(configExports));
 	}
 	return configExports || 'auto';
 }
@@ -436,7 +460,7 @@ const getInterop = (config: OutputOptions): NormalizedOutputOptions['interop'] =
 const validateInterop = (interop: InteropType): InteropType => {
 	if (!ALLOWED_INTEROP_TYPES.has(interop)) {
 		return error(
-			errorInvalidOption(
+			logInvalidOption(
 				'output.interop',
 				URL_OUTPUT_INTEROP,
 				// eslint-disable-next-line unicorn/prefer-spread
@@ -460,7 +484,7 @@ const getManualChunks = (
 	if (configManualChunks) {
 		if (inlineDynamicImports) {
 			return error(
-				errorInvalidOption(
+				logInvalidOption(
 					'output.manualChunks',
 					URL_OUTPUT_MANUALCHUNKS,
 					'this option is not supported for "output.inlineDynamicImports"'
@@ -469,7 +493,7 @@ const getManualChunks = (
 		}
 		if (preserveModules) {
 			return error(
-				errorInvalidOption(
+				logInvalidOption(
 					'output.manualChunks',
 					URL_OUTPUT_MANUALCHUNKS,
 					'this option is not supported for "output.preserveModules"'
@@ -505,16 +529,27 @@ const getNamespaceToStringTag = (
 	return generatedCode.symbols || false;
 };
 
+const getSourcemapFileNames = (
+	config: OutputOptions,
+	unsetOptions: Set<string>
+): NormalizedOutputOptions['sourcemapFileNames'] => {
+	const configSourcemapFileNames = config.sourcemapFileNames;
+	if (configSourcemapFileNames == null) {
+		unsetOptions.add('sourcemapFileNames');
+	}
+	return configSourcemapFileNames;
+};
+
 const getSourcemapBaseUrl = (
 	config: OutputOptions
 ): NormalizedOutputOptions['sourcemapBaseUrl'] => {
 	const { sourcemapBaseUrl } = config;
 	if (sourcemapBaseUrl) {
 		if (isValidUrl(sourcemapBaseUrl)) {
-			return sourcemapBaseUrl;
+			return addTrailingSlashIfMissed(sourcemapBaseUrl);
 		}
 		return error(
-			errorInvalidOption(
+			logInvalidOption(
 				'output.sourcemapBaseUrl',
 				URL_OUTPUT_SOURCEMAPBASEURL,
 				`must be a valid URL, received ${JSON.stringify(sourcemapBaseUrl)}`
