@@ -1,23 +1,22 @@
 import type { Bundle as MagicStringBundle, SourceMap } from 'magic-string';
-import type { ChunkRenderResult } from '../Chunk';
-import type Chunk from '../Chunk';
+import type { default as Chunk, ChunkRenderResult } from '../Chunk';
 import type Module from '../Module';
 import type {
 	DecodedSourceMapOrMissing,
+	LogHandler,
 	NormalizedOutputOptions,
-	RenderedChunk,
-	WarningHandler
+	RenderedChunk
 } from '../rollup/types';
 import type { PluginDriver } from './PluginDriver';
 import { collapseSourcemaps } from './collapseSourcemaps';
 import { createHash } from './crypto';
 import { decodedSourcemap } from './decodedSourcemap';
-import { error, errorFailedValidation } from './error';
 import {
 	replacePlaceholders,
 	replacePlaceholdersWithDefaultAndGetContainedPlaceholders,
 	replaceSinglePlaceholder
 } from './hashPlaceholders';
+import { error, logFailedValidation } from './logs';
 import type { OutputBundleWithPlaceholders } from './outputBundle';
 import { FILE_PLACEHOLDER, lowercaseBundleKeys } from './outputBundle';
 import { basename, normalize, resolve } from './path';
@@ -33,6 +32,7 @@ interface RenderedChunkWithPlaceholders {
 	chunk: Chunk;
 	code: string;
 	fileName: string;
+	sourcemapFileName: string | null;
 	map: SourceMap | null;
 }
 
@@ -41,7 +41,7 @@ export async function renderChunks(
 	bundle: OutputBundleWithPlaceholders,
 	pluginDriver: PluginDriver,
 	outputOptions: NormalizedOutputOptions,
-	onwarn: WarningHandler
+	log: LogHandler
 ) {
 	timeStart('render chunks', 2);
 
@@ -53,6 +53,7 @@ export async function renderChunks(
 
 	const chunkGraph = getChunkGraph(chunks);
 	const {
+		initialHashesByPlaceholder,
 		nonHashedChunksWithPlaceholders,
 		renderedChunksByPlaceholder,
 		hashDependenciesByPlaceholder
@@ -61,11 +62,12 @@ export async function renderChunks(
 		chunkGraph,
 		outputOptions,
 		pluginDriver,
-		onwarn
+		log
 	);
 	const hashesByPlaceholder = generateFinalHashes(
 		renderedChunksByPlaceholder,
 		hashDependenciesByPlaceholder,
+		initialHashesByPlaceholder,
 		bundle
 	);
 	addChunksToBundle(
@@ -105,7 +107,7 @@ async function transformChunk(
 	chunkGraph: Record<string, RenderedChunk>,
 	options: NormalizedOutputOptions,
 	outputPluginDriver: PluginDriver,
-	onwarn: WarningHandler
+	log: LogHandler
 ) {
 	let map: SourceMap | null = null;
 	const sourcemapChain: DecodedSourceMapOrMissing[] = [];
@@ -137,7 +139,8 @@ async function transformChunk(
 		sourcemap,
 		sourcemapExcludeSources,
 		sourcemapFile,
-		sourcemapPathTransform
+		sourcemapPathTransform,
+		sourcemapIgnoreList
 	} = options;
 	if (!compact && code[code.length - 1] !== '\n') code += '\n';
 
@@ -156,23 +159,31 @@ async function transformChunk(
 			usedModules,
 			sourcemapChain,
 			sourcemapExcludeSources,
-			onwarn
+			log
 		);
-		map.sources = map.sources
-			.map(sourcePath => {
-				if (sourcemapPathTransform) {
-					const newSourcePath = sourcemapPathTransform(sourcePath, `${resultingFile}.map`);
-
-					if (typeof newSourcePath !== 'string') {
-						error(errorFailedValidation(`sourcemapPathTransform function must return a string.`));
-					}
-
-					return newSourcePath;
+		for (let sourcesIndex = 0; sourcesIndex < map.sources.length; ++sourcesIndex) {
+			let sourcePath = map.sources[sourcesIndex];
+			const sourcemapPath = `${resultingFile}.map`;
+			const ignoreList = sourcemapIgnoreList(sourcePath, sourcemapPath);
+			if (typeof ignoreList !== 'boolean') {
+				error(logFailedValidation('sourcemapIgnoreList function must return a boolean.'));
+			}
+			if (ignoreList) {
+				if (map.x_google_ignoreList === undefined) {
+					map.x_google_ignoreList = [];
 				}
-
-				return sourcePath;
-			})
-			.map(normalize);
+				if (!map.x_google_ignoreList.includes(sourcesIndex)) {
+					map.x_google_ignoreList.push(sourcesIndex);
+				}
+			}
+			if (sourcemapPathTransform) {
+				sourcePath = sourcemapPathTransform(sourcePath, sourcemapPath);
+				if (typeof sourcePath !== 'string') {
+					error(logFailedValidation(`sourcemapPathTransform function must return a string.`));
+				}
+			}
+			map.sources[sourcesIndex] = normalize(sourcePath);
+		}
 
 		timeEnd('sourcemaps', 3);
 	}
@@ -187,11 +198,12 @@ async function transformChunksAndGenerateContentHashes(
 	chunkGraph: Record<string, RenderedChunk>,
 	outputOptions: NormalizedOutputOptions,
 	pluginDriver: PluginDriver,
-	onwarn: WarningHandler
+	log: LogHandler
 ) {
 	const nonHashedChunksWithPlaceholders: RenderedChunkWithPlaceholders[] = [];
 	const renderedChunksByPlaceholder = new Map<string, RenderedChunkWithPlaceholders>();
 	const hashDependenciesByPlaceholder = new Map<string, HashResult>();
+	const initialHashesByPlaceholder = new Map<string, string>();
 	const placeholders = new Set<string>();
 	for (const {
 		preliminaryFileName: { hashPlaceholder }
@@ -203,12 +215,14 @@ async function transformChunksAndGenerateContentHashes(
 			async ({
 				chunk,
 				preliminaryFileName: { fileName, hashPlaceholder },
+				preliminarySourcemapFileName,
 				magicString,
 				usedModules
 			}) => {
-				const transformedChunk = {
+				const transformedChunk: RenderedChunkWithPlaceholders = {
 					chunk,
 					fileName,
+					sourcemapFileName: preliminarySourcemapFileName?.fileName ?? null,
 					...(await transformChunk(
 						magicString,
 						fileName,
@@ -216,17 +230,17 @@ async function transformChunksAndGenerateContentHashes(
 						chunkGraph,
 						outputOptions,
 						pluginDriver,
-						onwarn
+						log
 					))
 				};
-				const { code } = transformedChunk;
+				const { code, map } = transformedChunk;
+
 				if (hashPlaceholder) {
-					const hash = createHash();
 					// To create a reproducible content-only hash, all placeholders are
 					// replaced with the same value before hashing
 					const { containedPlaceholders, transformedCode } =
 						replacePlaceholdersWithDefaultAndGetContainedPlaceholders(code, placeholders);
-					hash.update(transformedCode);
+					const hash = createHash().update(transformedCode);
 					const hashAugmentation = pluginDriver.hookReduceValueSync(
 						'augmentChunkHash',
 						'',
@@ -249,11 +263,23 @@ async function transformChunksAndGenerateContentHashes(
 				} else {
 					nonHashedChunksWithPlaceholders.push(transformedChunk);
 				}
+
+				const sourcemapHashPlaceholder = preliminarySourcemapFileName?.hashPlaceholder;
+				if (map && sourcemapHashPlaceholder) {
+					initialHashesByPlaceholder.set(
+						preliminarySourcemapFileName.hashPlaceholder,
+						createHash()
+							.update(map.toString())
+							.digest('hex')
+							.slice(0, preliminarySourcemapFileName.hashPlaceholder.length)
+					);
+				}
 			}
 		)
 	);
 	return {
 		hashDependenciesByPlaceholder,
+		initialHashesByPlaceholder,
 		nonHashedChunksWithPlaceholders,
 		renderedChunksByPlaceholder
 	};
@@ -262,9 +288,10 @@ async function transformChunksAndGenerateContentHashes(
 function generateFinalHashes(
 	renderedChunksByPlaceholder: Map<string, RenderedChunkWithPlaceholders>,
 	hashDependenciesByPlaceholder: Map<string, HashResult>,
+	initialHashesByPlaceholder: Map<string, string>,
 	bundle: OutputBundleWithPlaceholders
 ) {
-	const hashesByPlaceholder = new Map<string, string>();
+	const hashesByPlaceholder = new Map<string, string>(initialHashesByPlaceholder);
 	for (const [placeholder, { fileName }] of renderedChunksByPlaceholder) {
 		let hash = createHash();
 		const hashDependencyPlaceholders = new Set<string>([placeholder]);
@@ -282,8 +309,7 @@ function generateFinalHashes(
 		do {
 			// In case of a hash collision, create a hash of the hash
 			if (finalHash) {
-				hash = createHash();
-				hash.update(finalHash);
+				hash = createHash().update(finalHash);
 			}
 			finalHash = hash.digest('hex').slice(0, placeholder.length);
 			finalFileName = replaceSinglePlaceholder(fileName, placeholder, finalHash);
@@ -302,22 +328,46 @@ function addChunksToBundle(
 	pluginDriver: PluginDriver,
 	options: NormalizedOutputOptions
 ) {
-	for (const { chunk, code, fileName, map } of renderedChunksByPlaceholder.values()) {
+	for (const {
+		chunk,
+		code,
+		fileName,
+		sourcemapFileName,
+		map
+	} of renderedChunksByPlaceholder.values()) {
 		let updatedCode = replacePlaceholders(code, hashesByPlaceholder);
 		const finalFileName = replacePlaceholders(fileName, hashesByPlaceholder);
+		let finalSourcemapFileName = null;
 		if (map) {
+			finalSourcemapFileName = sourcemapFileName
+				? replacePlaceholders(sourcemapFileName, hashesByPlaceholder)
+				: `${finalFileName}.map`;
 			map.file = replacePlaceholders(map.file, hashesByPlaceholder);
-			updatedCode += emitSourceMapAndGetComment(finalFileName, map, pluginDriver, options);
+			updatedCode += emitSourceMapAndGetComment(finalSourcemapFileName, map, pluginDriver, options);
 		}
-		bundle[finalFileName] = chunk.finalizeChunk(updatedCode, map, hashesByPlaceholder);
+		bundle[finalFileName] = chunk.finalizeChunk(
+			updatedCode,
+			map,
+			finalSourcemapFileName,
+			hashesByPlaceholder
+		);
 	}
-	for (const { chunk, code, fileName, map } of nonHashedChunksWithPlaceholders) {
+	for (const { chunk, code, fileName, sourcemapFileName, map } of nonHashedChunksWithPlaceholders) {
 		let updatedCode =
 			hashesByPlaceholder.size > 0 ? replacePlaceholders(code, hashesByPlaceholder) : code;
+		let finalSourcemapFileName = null;
 		if (map) {
-			updatedCode += emitSourceMapAndGetComment(fileName, map, pluginDriver, options);
+			finalSourcemapFileName = sourcemapFileName
+				? replacePlaceholders(sourcemapFileName, hashesByPlaceholder)
+				: `${fileName}.map`;
+			updatedCode += emitSourceMapAndGetComment(finalSourcemapFileName, map, pluginDriver, options);
 		}
-		bundle[fileName] = chunk.finalizeChunk(updatedCode, map, hashesByPlaceholder);
+		bundle[fileName] = chunk.finalizeChunk(
+			updatedCode,
+			map,
+			finalSourcemapFileName,
+			hashesByPlaceholder
+		);
 	}
 }
 
@@ -331,11 +381,11 @@ function emitSourceMapAndGetComment(
 	if (sourcemap === 'inline') {
 		url = map.toUrl();
 	} else {
-		const sourcemapFileName = `${basename(fileName)}.map`;
+		const sourcemapFileName = basename(fileName);
 		url = sourcemapBaseUrl
 			? new URL(sourcemapFileName, sourcemapBaseUrl).toString()
 			: sourcemapFileName;
-		pluginDriver.emitFile({ fileName: `${fileName}.map`, source: map.toString(), type: 'asset' });
+		pluginDriver.emitFile({ fileName, source: map.toString(), type: 'asset' });
 	}
 	return sourcemap === 'hidden' ? '' : `//# ${SOURCEMAPPING_URL}=${url}\n`;
 }
