@@ -1,12 +1,12 @@
-System.register([], function (exports, module) {
+System.register([], (function (exports, module) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			console.log('main1');
 			module.import('./generated-main4.dynamic.js');
 			module.import('./generated-main5.js');
 
-		}
+		})
 	};
-});
+}));
