@@ -2,7 +2,7 @@ const assert = require('node:assert');
 const fs = require('node:fs');
 const path = require('node:path');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'does not emit unreferenced assets if needsCodeReference is true',
 	options: {
 		output: {
@@ -32,4 +32,4 @@ module.exports = {
 			}
 		]
 	}
-};
+});
