@@ -1,21 +1,21 @@
-define(['./generated-dep2'], function (dep2) { 'use strict';
+define(['./generated-dep2'], (function (dep2) { 'use strict';
 
-  function fn () {
+  function fn$1 () {
     console.log('lib1 fn');
   }
 
-  function fn$1 () {
-    fn();
+  function fn () {
+    fn$1();
     console.log('dep3 fn');
   }
 
   class Main2 {
     constructor () {
-      fn$1();
+      fn();
       dep2.fn();
     }
   }
 
   return Main2;
 
-});
+}));
