@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'maintains execution order ',
 	options: {
 		input: ['main1.js', 'main2.js', 'main3.js', 'main4.js']
 	}
-};
+});
