@@ -1,3 +1,3 @@
-import './dep111';
+import './dep111.js';
 export { x } from './dep112.js';
 console.log('11');
