@@ -1,8 +1,8 @@
-System.register(['./generated-one.js'], (function (exports) {
+System.register(['./generated-main1.js'], (function (exports) {
 	'use strict';
 	return {
 		setters: [function (module) {
-			exports('ItemOne', module.O);
+			exports('ItemOne', module.a);
 		}],
 		execute: (function () {
 
