@@ -1,9 +1,9 @@
-System.register(['./generated-one.js'], (function (exports) {
+System.register(['./generated-main1.js'], (function (exports) {
     'use strict';
     var ONE_CONSTANT;
     return {
         setters: [function (module) {
-            ONE_CONSTANT = module.a;
+            ONE_CONSTANT = module.O;
         }],
         execute: (function () {
 
