@@ -1,4 +1,4 @@
-define(['./generated-dep1'], function (dep1) { 'use strict';
+define(['./generated-dep1'], (function (dep1) { 'use strict';
 
   class Main2 {
     constructor () {
@@ -9,4 +9,4 @@ define(['./generated-dep1'], function (dep1) { 'use strict';
 
   return Main2;
 
-});
+}));
