@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'chunk with a namespace boundary',
 	options: {
 		input: ['main1.js', 'main2.js']
 	}
-};
+});
