@@ -2,4 +2,4 @@ import { s as shared } from './generated-shared.js';
 
 var main2 = shared.map(d => d + 2);
 
-export default main2;
+export { main2 as default };
