@@ -1,11 +1,11 @@
-System.register([], function (exports) {
+System.register([], (function (exports) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			var value = exports('v', 42);
 			const x = exports('x', 3);
 
-		}
+		})
 	};
-});
+}));
