@@ -1,8 +1,8 @@
-'use strict';var __chunk_1=require('./generated-chunk.js');function fn () {
+'use strict';var dep2=require('./generated-dep2.js');function fn () {
   console.log('dep1 fn');
 }class Main1 {
   constructor () {
     fn();
-    __chunk_1.a();
+    dep2.f();
   }
 }module.exports=Main1;
\ No newline at end of file
