@@ -15,7 +15,7 @@ Object.defineProperty(exports, 'e', {
 exports.dep = dep.dep;
 exports.main = main;
 Object.keys(starexternal1).forEach(function (k) {
-	if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
+	if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
 		enumerable: true,
 		get: function () { return starexternal1[k]; }
 	});
