@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'chunking circular entry points',
 	expectedWarnings: ['CIRCULAR_DEPENDENCY'],
 	options: {
 		input: ['main1.js', 'main2.js']
 	}
-};
+});
