@@ -1,10 +1,10 @@
 define(['exports'], (function (exports) { 'use strict';
 
-  class C$1 {
+  let C$1 = class C {
     fn (num) {
       console.log(num - p);
     }
-  }
+  };
 
   var p$1 = 43;
 
