@@ -1,8 +1,8 @@
-class C$1 {
+let C$1 = class C {
   fn (num) {
     console.log(num - p);
   }
-}
+};
 
 var p$1 = 43;
 
