@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deconflicts SystemJS default export variable with namespace imports',
 	options: {
 		external: 'external',
 		output: { preserveModules: true }
 	}
-};
+});
