@@ -2,4 +2,4 @@ import { d as data } from './generated-shared.js';
 
 var main1 = data.map(d => d + 1);
 
-export default main1;
+export { main1 as default };
