@@ -4,13 +4,10 @@ System.register([], (function (exports) {
 		execute: (function () {
 
 			const bar = exports('bar', 2);
-			Promise.resolve().then(function () { return foo$1; });
+			Promise.resolve().then(function () { return foo; });
 
-			const foo = 1;
-
-			var foo$1 = /*#__PURE__*/Object.freeze({
-				__proto__: null,
-				foo: foo
+			var foo = /*#__PURE__*/Object.freeze({
+				__proto__: null
 			});
 
 		})
