@@ -1,10 +1,10 @@
-System.register([], function (exports, module) {
+System.register([], (function (exports, module) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			module.import('./foo.js').then(result => console.log(result));
 
-		}
+		})
 	};
-});
+}));
