@@ -1,7 +1,7 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
 	console.log('dep2');
 
 	console.log('dep-b');
 
-});
+}));
