@@ -1,20 +1,20 @@
-define(['exports', './generated-lib1'], function (exports, lib1) { 'use strict';
+define(['exports', './generated-lib1'], (function (exports, lib1) { 'use strict';
 
-  function fn () {
+  function fn$2 () {
     console.log('lib2 fn');
   }
 
   function fn$1 () {
-    fn();
+    fn$2();
     console.log('dep2 fn');
   }
 
-  function fn$2 () {
+  function fn () {
     lib1.fn();
     console.log('dep3 fn');
   }
 
   exports.fn = fn$1;
-  exports.fn$1 = fn$2;
+  exports.fn$1 = fn;
 
-});
+}));
