@@ -1,5 +1,6 @@
 'use strict';
 
+var _commonjsHelpers = require('./_virtual/_commonjsHelpers.js');
 var require$$0 = require('external');
 require('./other.js');
 var other = require('./_virtual/other.js');
@@ -11,4 +12,6 @@ console.log(external, value);
 
 var commonjs = 42;
 
-module.exports = commonjs;
+var value$1 = /*@__PURE__*/_commonjsHelpers.getDefaultExportFromCjs(commonjs);
+
+module.exports = value$1;
