@@ -1,6 +1,6 @@
 const path = require('node:path');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'scriptified assets have extension in preserveModules output filename',
 	options: {
 		strictDeprecations: false,
@@ -29,4 +29,4 @@ module.exports = {
 		]
 	},
 	expectedWarnings: ['DEPRECATED_FEATURE']
-};
+});
