@@ -1,11 +1,11 @@
-System.register(['./generated-main.js'], function (exports) {
+System.register(['./generated-main.js'], (function (exports) {
   'use strict';
   var multiplier;
   return {
     setters: [function (module) {
       multiplier = module.m;
     }],
-    execute: function () {
+    execute: (function () {
 
       exports('mult', mult);
 
@@ -13,6 +13,6 @@ System.register(['./generated-main.js'], function (exports) {
         return num + multiplier;
       }
 
-    }
+    })
   };
-});
+}));
