@@ -1,5 +1,5 @@
 'use strict';
 
-var dynamic = require('./generated-chunk.js');
+var dynamic = require('./generated-dynamic.js');
 
 console.log('main2', dynamic.dynamic, dynamic.dep);
