@@ -2,5 +2,4 @@ var separate = 'separate';
 const x = 2;
 console.log('separate');
 
-export default separate;
-export { x };
+export { separate as default, x };
