@@ -6,7 +6,7 @@ console.log('inlined');
 
 var inlined$2 = /*#__PURE__*/Object.freeze({
 	__proto__: null,
-	'default': inlined$1,
+	default: inlined$1,
 	x: x
 });
 
