@@ -1,10 +1,10 @@
-System.register([], function (exports, module) {
+System.register([], (function (exports, module) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			const separate = exports('separate', module.import('./generated-separate.js'));
 
-		}
+		})
 	};
-});
+}));
