@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'supports an object with a single entry when inlining dynamic imports',
 	options: {
 		output: { inlineDynamicImports: true },
 		input: { entry: 'main' }
 	}
-};
+});
