@@ -1,3 +1,3 @@
 var main = Promise.all([import('./entry.js'), import('./generated-other.js')]);
 
-export default main;
+export { main as default };
