@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles dynamic imports when the imported module only reexports from other modules',
 	options: {
 		input: ['main']
 	}
-};
+});
