@@ -1,5 +1,5 @@
 'use strict';
 
-var dep1 = require('./generated-chunk.js');
+var dep1 = require('./generated-dep1.js');
 
 console.log(dep1.foo(), dep1.bar());
