@@ -1,7 +1,7 @@
-System.register([], function (exports) {
+System.register([], (function (exports) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			exports({
 				b: bar,
@@ -24,6 +24,6 @@ System.register([], function (exports) {
 			});
 			exports('d', dep1);
 
-		}
+		})
 	};
-});
+}));
