@@ -1,10 +1,10 @@
-System.register([], function (exports, module) {
+System.register([], (function (exports, module) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			module.import('./generated-dep1.js').then(function (n) { return n.d; }).then(({ bar }) => console.log(bar()));
 
-		}
+		})
 	};
-});
+}));
