@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'uses existing entry facades for dynamic imports if present',
 	options: {
 		input: ['main.js', 'importer.js'],
 		preserveEntrySignatures: 'strict'
 	}
-};
+});
