@@ -1,7 +1,7 @@
 'use strict';
 
 var name = require('./generated-name.js');
-var secondName = require('./generated-secondName.js');
+var firstName = require('./generated-firstName.js');
 var name$1 = require('./generated-name2.js');
 
-console.log('main', name, secondName, name$1);
+console.log('main', name, firstName, name$1);
