@@ -1,7 +1,7 @@
 const assert = require('node:assert');
 let referenceId;
 
-module.exports = {
+module.exports = defineTest({
 	description: 'allows adding additional chunks and retrieving their file name',
 	options: {
 		input: 'main',
@@ -22,4 +22,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
