@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows adding additional chunks and retrieving their file name',
 	options: {
 		input: 'main',
@@ -18,4 +18,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
