@@ -1,12 +1,12 @@
-System.register([], function () {
+System.register([], (function () {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			var value = 42;
 
 			console.log('main', value);
 
-		}
+		})
 	};
-});
+}));
