@@ -3,17 +3,15 @@ System.register([], (function (exports, module) {
 	return {
 		execute: (function () {
 
-			const renderStart = exports('renderStart', new URL('assets/renderStart-66600c78.txt', module.meta.url).href);
+			const renderStart = exports('renderStart', new URL('assets/renderStart-981aa2ea.txt', module.meta.url).href);
 			const renderStartNamed = exports('renderStartNamed', new URL('renderStart.txt', module.meta.url).href);
 			const renderStartNamedImmediately = exports('renderStartNamedImmediately', 'renderStart.txt');
-			const banner = exports('banner', new URL('assets/banner-2b65cc0c.txt', module.meta.url).href);
 			const bannerNamed = exports('bannerNamed', new URL('banner.txt', module.meta.url).href);
-			const footer = exports('footer', new URL('assets/footer-e1d2fccb.txt', module.meta.url).href);
 			const footerNamed = exports('footerNamed', new URL('footer.txt', module.meta.url).href);
-			const intro = exports('intro', new URL('assets/intro-520a8116.txt', module.meta.url).href);
 			const introNamed = exports('introNamed', new URL('intro.txt', module.meta.url).href);
-			const outro = exports('outro', new URL('assets/outro-21f77720.txt', module.meta.url).href);
 			const outroNamed = exports('outroNamed', new URL('outro.txt', module.meta.url).href);
+			const renderChunkNamed = exports('renderChunkNamed', new URL('renderChunk.txt', module.meta.url).href);
+			const generateBundleNamed = exports('generateBundleNamed', new URL('generateBundle.txt', module.meta.url).href);
 
 		})
 	};
