@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'empty chunk pruning',
 	expectedWarnings: ['EMPTY_BUNDLE'],
 	options: {
 		input: ['main1.js', 'main2.js']
 	}
-};
+});
