@@ -1,4 +1,4 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
   function fn () {
     console.log('main fn');
@@ -6,4 +6,4 @@ define(function () { 'use strict';
 
   return fn;
 
-});
+}));
