@@ -5,8 +5,8 @@ var bar = require('external-namespace');
 var quux = require('external-default-namespace');
 var quux$1 = require('external-named-namespace');
 
-function _interopNamespace(e) {
-	if (e && e.__esModule) return e;
+function _interopNamespaceCompat(e) {
+	if (e && typeof e === 'object' && 'default' in e) return e;
 	var n = Object.create(null);
 	if (e) {
 		Object.keys(e).forEach(function (k) {
@@ -19,13 +19,13 @@ function _interopNamespace(e) {
 			}
 		});
 	}
-	n["default"] = e;
+	n.default = e;
 	return Object.freeze(n);
 }
 
-var foo__namespace = /*#__PURE__*/_interopNamespace(foo);
-var bar__namespace = /*#__PURE__*/_interopNamespace(bar);
-var quux__namespace = /*#__PURE__*/_interopNamespace(quux);
-var quux__namespace$1 = /*#__PURE__*/_interopNamespace(quux$1);
+var foo__namespace = /*#__PURE__*/_interopNamespaceCompat(foo);
+var bar__namespace = /*#__PURE__*/_interopNamespaceCompat(bar);
+var quux__namespace = /*#__PURE__*/_interopNamespaceCompat(quux);
+var quux__namespace$1 = /*#__PURE__*/_interopNamespaceCompat(quux$1);
 
 console.log(foo__namespace, bar__namespace, quux__namespace, quux__namespace$1);
