@@ -1,4 +1,4 @@
-System.register(['external-all', 'external-named', 'external-default-named', 'external-named-namespace'], function () {
+System.register(['external-all', 'external-named', 'external-default-named', 'external-named-namespace'], (function () {
 	'use strict';
 	var foo, bar, baz, quux;
 	return {
@@ -11,10 +11,10 @@ System.register(['external-all', 'external-named', 'external-default-named', 'ex
 		}, function (module) {
 			quux = module.quux;
 		}],
-		execute: function () {
+		execute: (function () {
 
 			console.log(foo, bar, baz, quux);
 
-		}
+		})
 	};
-});
+}));
