@@ -1,4 +1,4 @@
-System.register(['external-all', 'external-namespace', 'external-default-namespace', 'external-named-namespace'], function (exports) {
+System.register(['external-all', 'external-namespace', 'external-default-namespace', 'external-named-namespace'], (function (exports) {
 	'use strict';
 	return {
 		setters: [function (module) {
@@ -10,12 +10,12 @@ System.register(['external-all', 'external-namespace', 'external-default-namespa
 		}, function (module) {
 			exports('quux', module);
 		}],
-		execute: function () {
+		execute: (function () {
 
 			const externalNamespace = 1;
 			const externalNamespace__ns = 1;
 			console.log(externalNamespace, externalNamespace__ns);
 
-		}
+		})
 	};
-});
+}));
