@@ -1,12 +1,12 @@
-System.register([], function (exports) {
+System.register([], (function (exports) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			const lib1 = exports('l', 'lib1');
 
 			const lib1b = exports('a', 'lib1b');
 
-		}
+		})
 	};
-});
+}));
