@@ -1,4 +1,4 @@
-System.register(['./generated-lib1b.js', './generated-lib3.js'], function () {
+System.register(['./generated-lib1b.js', './generated-lib3.js'], (function () {
 	'use strict';
 	var lib1, lib1b, lib3;
 	return {
@@ -8,10 +8,10 @@ System.register(['./generated-lib1b.js', './generated-lib3.js'], function () {
 		}, function (module) {
 			lib3 = module.l;
 		}],
-		execute: function () {
+		execute: (function () {
 
 			console.log('main2', lib1, lib1b, lib3);
 
-		}
+		})
 	};
-});
+}));
