@@ -1,13 +1,13 @@
-System.register([], function (exports, module) {
+System.register([], (function (exports, module) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			const value = exports('v', 42);
 
 			console.log(value);
 			module.import('./generated-dynamicDep.js');
 
-		}
+		})
 	};
-});
+}));
