@@ -1,7 +1,7 @@
-System.register([], function (exports, module) {
+System.register([], (function (exports, module) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			const value = exports('v', 42);
 
@@ -9,6 +9,6 @@ System.register([], function (exports, module) {
 			module.import('./generated-dynamicDep.js');
 			const dep = exports('d', 'dep');
 
-		}
+		})
 	};
-});
+}));
