@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'supports nested numeric paths without issues on Windows',
 	options: {
 		output: { preserveModules: true },
@@ -13,4 +13,4 @@ module.exports = {
 			}
 		]
 	}
-};
+});
