@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'inlines dynamic imports that are already statically imported by their importers'
-};
+});
