@@ -1,4 +1,5 @@
 import { value } from './generated-dynamic1.js';
-export { value } from './generated-dynamic1.js';
 
 console.log('dynamic2', value);
+
+export { value };
