@@ -1,7 +1,7 @@
-define(['exports'], function (exports) { 'use strict';
+define(['exports'], (function (exports) { 'use strict';
 
 	const value1 = 'main1 and dynamic';
 
 	exports.value1 = value1;
 
-});
+}));
