@@ -1,4 +1,4 @@
-System.register(['./generated-from-main-1-and-dynamic.js', './generated-from-main-1-and-2.js'], function (exports) {
+System.register(['./generated-from-main-1-and-dynamic.js', './generated-from-main-1-and-2.js'], (function (exports) {
 	'use strict';
 	var value1, value2;
 	return {
@@ -9,10 +9,10 @@ System.register(['./generated-from-main-1-and-dynamic.js', './generated-from-mai
 			value2 = module.v;
 			exports('value2', module.v);
 		}],
-		execute: function () {
+		execute: (function () {
 
 			console.log('dynamic1', value1, value2);
 
-		}
+		})
 	};
-});
+}));
