@@ -1,4 +1,4 @@
-System.register(['./generated-dep1.js', './generated-dep2.js'], function (exports, module) {
+System.register(['./generated-dep1.js', './generated-dep2.js'], (function (exports, module) {
 	'use strict';
 	var value1, value2;
 	return {
@@ -9,13 +9,13 @@ System.register(['./generated-dep1.js', './generated-dep2.js'], function (export
 			value2 = module.v;
 			exports('value2', module.v);
 		}],
-		execute: function () {
+		execute: (function () {
 
 			const something = 'something';
 
 			console.log('main1', value1, value2, something);
 			module.import('./generated-dynamic.js');
 
-		}
+		})
 	};
-});
+}));
