@@ -1,5 +1,6 @@
 import { value1 } from './main1.js';
-export { value1 } from './main1.js';
 import './generated-dep2.js';
 
 console.log('dynamic1', value1);
+
+export { value1 };
