@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not drop indirect reexports when preserving modules',
 	expectedWarnings: ['MIXED_EXPORTS'],
 	options: {
 		output: { name: 'bundle', preserveModules: true }
 	}
-};
+});
