@@ -2,6 +2,6 @@ define(['external-esModule'], (function (externalEsModule) { 'use strict';
 
 
 
-	return externalEsModule["default"];
+	return externalEsModule.default;
 
 }));
