@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	expectedWarnings: ['EMPTY_BUNDLE'],
 	description: 'Uses entry alias if manual chunks contain entry chunks with different alias',
 	options: {
@@ -12,4 +12,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
