@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'Identifies the entry chunk with the manual chunk that contains it if the aliases match',
 	options: {
@@ -11,4 +11,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
