@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Uses entry alias if manual chunks are entry chunks with different alias',
 	options: {
 		input: {
@@ -11,4 +11,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
