@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows to force the minification of internal exports',
 	options: {
 		input: ['main1.js', 'main2.js'],
@@ -6,4 +6,4 @@ module.exports = {
 			minifyInternalExports: true
 		}
 	}
-};
+});
