@@ -1,3 +1,3 @@
-var _missingExportShim=void 0;function x () {
-  sideEffect();
+var _missingExportShim=void 0;function x (arg) {
+  sideEffect(arg);
 }export{_missingExportShim as missingExport,_missingExportShim as missingFn,x};
\ No newline at end of file
