@@ -1,4 +1,4 @@
-System.register(['./generated-dep2.js', './generated-dep3.js'], function () {
+System.register(['./generated-dep2.js', './generated-dep3.js'], (function () {
 	'use strict';
 	var num, num$1;
 	return {
@@ -7,10 +7,10 @@ System.register(['./generated-dep2.js', './generated-dep3.js'], function () {
 		}, function (module) {
 			num$1 = module.n;
 		}],
-		execute: function () {
+		execute: (function () {
 
 			console.log(num + num$1);
 
-		}
+		})
 	};
-});
+}));
