@@ -1,9 +1,9 @@
-System.register(['./chunks/shared.js'], (function () {
+System.register(['./other.js'], (function () {
 	'use strict';
 	var sharedValue;
 	return {
 		setters: [function (module) {
-			sharedValue = module.s;
+			sharedValue = module.sharedValue;
 		}],
 		execute: (function () {
 
