@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'renders namespaces with reexports that conflict with existing imports',
 	options: {
 		input: ['main1.js', 'main2.js', 'main3.js'],
@@ -7,4 +7,4 @@ module.exports = {
 			exports: 'named'
 		}
 	}
-};
+});
