@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'namespace rendering with reexports',
 	options: {
 		input: ['main.js', 'hsl2hsv.js', 'index.js'],
@@ -6,4 +6,4 @@ module.exports = {
 			exports: 'named'
 		}
 	}
-};
+});
