@@ -6,7 +6,7 @@ define(['exports', './hsl2hsv'], (function (exports, hsl2hsv$1) { 'use strict';
 
 	var lib = /*#__PURE__*/Object.freeze({
 		__proto__: null,
-		hsl2hsv: hsl2hsv$1["default"]
+		hsl2hsv: hsl2hsv$1.default
 	});
 
 	exports.lib = lib;
