@@ -1,2 +1,2 @@
 export { default as hsl2hsv } from './hsl2hsv.js';
-import './generated-chunk.js';
+import './generated-index.js';
