@@ -4,4 +4,4 @@ import { p } from './hsl2hsv.js';
 console.log(p);
 var main = new Map(Object.entries(lib));
 
-export default main;
+export { main as default };
