@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'internal reexported namespaces over chunk boundaries',
 	options: {
 		input: ['main-a.js', 'main-b.js']
 	}
-};
+});
