@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'adds Symbol.toStringTag property to dynamic imports of entry chunks with default export mode',
 	options: {
@@ -7,4 +7,4 @@ module.exports = {
 			generatedCode: { symbols: true }
 		}
 	}
-};
+});
