@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles dynamic imports containing dynamic imports',
 	options: {
 		input: 'main'
 	}
-};
+});
