@@ -1,11 +1,11 @@
-System.register([], function (exports, module) {
+System.register([], (function (exports, module) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			module.import('./generated-dynamic1.js');
 			console.log('main');
 
-		}
+		})
 	};
-});
+}));
