@@ -1,13 +1,13 @@
-System.register(['./generated-main.js'], function (exports) {
+System.register(['./generated-main.js'], (function (exports) {
 	'use strict';
 	return {
 		setters: [function (module) {
 			exports('unused', module.u);
 		}],
-		execute: function () {
+		execute: (function () {
 
 
 
-		}
+		})
 	};
-});
+}));
