@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Creates a facade if necessary for strict entry signatures',
 	options: {
 		preserveEntrySignatures: 'strict'
 	}
-};
+});
