@@ -1,6 +1,6 @@
 const commonjs = require('@rollup/plugin-commonjs');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'Handles output from @rollup/plugin-commonjs',
 	expectedWarnings: ['MIXED_EXPORTS'],
 	options: {
@@ -9,4 +9,4 @@ module.exports = {
 		plugins: [commonjs()],
 		output: { preserveModules: true }
 	}
-};
+});
