@@ -1,6 +1,6 @@
 define(['./lib'], (function (lib) { 'use strict';
 
-	function _interopNamespaceDefaultOnly (e) { return Object.freeze({ __proto__: null, 'default': e }); }
+	function _interopNamespaceDefaultOnly (e) { return Object.freeze({ __proto__: null, default: e }); }
 
 	var lib__namespace = /*#__PURE__*/_interopNamespaceDefaultOnly(lib);
 
