@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'dynamic imports are handled correctly when preserving modules',
 	options: {
 		input: ['main.js'],
 		output: { preserveModules: true }
 	}
-};
+});
