@@ -1,13 +1,13 @@
-System.register(['./dep.js'], function (exports, module) {
+System.register(['./dep.js'], (function (exports) {
 	'use strict';
 	return {
 		setters: [function (module) {
 			exports('bar', module.foo);
 		}],
-		execute: function () {
+		execute: (function () {
 
 
 
-		}
+		})
 	};
-});
+}));
