@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'respects "named" export mode in all chunks when preserving modules',
 	options: {
 		input: 'main.js',
@@ -7,4 +7,4 @@ module.exports = {
 			preserveModules: true
 		}
 	}
-};
+});
