@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'confirm exports are deconflicted when exporting nested index aliases',
 	options: {
 		input: 'main.js',
 		output: { preserveModules: true }
 	}
-};
+});
