@@ -1,10 +1,10 @@
-System.register([], function (exports) {
+System.register([], (function (exports) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			const TEST_MODULE_B = exports('TEST_MODULE_B', 'A');
 
-		}
+		})
 	};
-});
+}));
