@@ -1,8 +1,8 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'correctly resolves imports via a proxy module as direct imports when preserving modules',
 	options: {
 		external: 'external',
 		output: { preserveModules: true }
 	}
-};
+});
