@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'change the module destination',
 	options: {
 		input: 'src/lib/main.js',
 		output: { preserveModules: true }
 	}
-};
+});
