@@ -1,7 +1,7 @@
 const commonjs = require('@rollup/plugin-commonjs');
 const resolve = require('@rollup/plugin-node-resolve').default;
 
-module.exports = {
+module.exports = defineTest({
 	description: 'confirm preserveModulesRoot restructures src appropriately',
 	expectedWarnings: ['MIXED_EXPORTS'],
 	options: {
@@ -25,4 +25,4 @@ module.exports = {
 			preserveModulesRoot: 'src'
 		}
 	}
-};
+});
