@@ -1,6 +1,6 @@
 'use strict';
 
-var index = require('../../../_virtual/index.js_commonjs-exports.js');
+var index = require('../../../_virtual/index.js');
 
 Object.defineProperty(index.__exports, '__esModule', { value: true });
 
