@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'Generates actual files whose filename adheres to entryFileNames for virtual modules when preserving modules',
 	options: {
@@ -31,4 +31,4 @@ module.exports = {
 			}
 		]
 	}
-};
+});
