@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Rewrite modules in-place',
 	options: {
 		input: ['main1.js', 'main2.js'],
 		output: { preserveModules: true }
 	}
-};
+});
