@@ -1,4 +1,4 @@
-System.register(['./generated-dep2.js'], (function (exports) {
+System.register(['./main2.js'], (function (exports) {
 	'use strict';
 	var foo;
 	return {
