@@ -24,12 +24,10 @@ define(['require', './direct-relative-external', 'to-indirect-relative-external'
 	new Promise(function (resolve, reject) { require(['direct-absolute-external'], function (m) { resolve(/*#__PURE__*/_interopNamespaceDefault(m)); }, reject); });
 	new Promise(function (resolve, reject) { require(['to-indirect-absolute-external'], function (m) { resolve(/*#__PURE__*/_interopNamespaceDefault(m)); }, reject); });
 
-	const value = 'existing';
 	console.log('existing');
 
 	var existing = /*#__PURE__*/Object.freeze({
-		__proto__: null,
-		value: value
+		__proto__: null
 	});
 
 	//main
