@@ -11,12 +11,10 @@ System.register(['./direct-relative-external', 'to-indirect-relative-external',
 			module.import('direct-absolute-external');
 			module.import('to-indirect-absolute-external');
 
-			const value = 'existing';
 			console.log('existing');
 
 			var existing = /*#__PURE__*/Object.freeze({
-				__proto__: null,
-				value: value
+				__proto__: null
 			});
 
 			//main
