@@ -1,7 +1,7 @@
 System.register(['./generated-dep2-effect.js', './generated-dep4-effect.js'], (function () {
 	'use strict';
 	return {
-		setters: [function () {}, function () {}],
+		setters: [null, null],
 		execute: (function () {
 
 			console.log('main2');
