@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'handles synthetic named exports that are reexported as a default export over several stages',
 	options: {
@@ -9,4 +9,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
