@@ -19,7 +19,7 @@ var component = { lib, lib2: lib.named, lib3: lib.named.named };
 
 var component$1 = /*#__PURE__*/_mergeNamespaces({
 	__proto__: null,
-	'default': component
+	default: component
 }, [component]);
 
 export { component$1 as c };
