@@ -1,3 +1,3 @@
 import { named } from './lib-reexport2.js';
 console.log('side-effect', named);
-export default named;
+export { named as default };
