@@ -1,3 +1,3 @@
-import { l as lib } from './generated-lib.js';
+import { lib } from './main1.js';
 
 console.log(lib, lib.foo, lib.bar, lib.baz);
