@@ -23,8 +23,8 @@ System.register([], (function (exports) {
 
 			var dep$1 = /*#__PURE__*/_mergeNamespaces({
 				__proto__: null,
-				default: dep,
-				bar: bar
+				bar: bar,
+				default: dep
 			}, [dep]);
 			exports('d', dep$1);
 
