@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not expose the synthetic namespace if an entry point uses a string value',
 	options: {
 		input: ['main', 'other'],
@@ -10,4 +10,4 @@ module.exports = {
 			}
 		]
 	}
-};
+});
