@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles multiple levels of synthetic named exports',
 	options: {
 		input: ['main.js', 'main2.js', 'main3.js', 'main4.js', 'main5.js'],
@@ -14,4 +14,4 @@ module.exports = {
 			}
 		]
 	}
-};
+});
