@@ -36,8 +36,8 @@ var dep$1 = /*#__PURE__*/_mergeNamespaces({
 	__proto__: null,
 	bar: bar,
 	default: dep,
-	synthetic: synthetic$1,
-	foo: foo
+	foo: foo,
+	synthetic: synthetic$1
 }, [synthetic]);
 
 exports.dep = dep$1;
