@@ -1,14 +1,14 @@
-System.register(['./generated-dep.js'], function () {
+System.register(['./generated-dep.js'], (function () {
 	'use strict';
 	var dep;
 	return {
 		setters: [function (module) {
 			dep = module.d;
 		}],
-		execute: function () {
+		execute: (function () {
 
 			console.log('2', dep);
 
-		}
+		})
 	};
-});
+}));
