@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'allows defining names via CLI',
 	command:
 		'rollup entry1=main1.js "Entry 2"="main 2.js" "main3.js" --entryFileNames [name]-[hash].js -f es',
@@ -18,4 +18,4 @@ module.exports = {
 				"console.log('main3');\n"
 		);
 	}
-};
+});
