@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'allows defining names via CLI',
 	command:
 		'rollup --entryFileNames [name]-[hash].js --input entry1=main1.js -i "Entry 2"="main 2.js" -i "main3.js"  -f es',
@@ -18,4 +18,4 @@ module.exports = {
 				"console.log('main3');\n"
 		);
 	}
-};
+});
