@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'supports using an async function as config',
 	command: 'rollup -c'
-};
+});
