@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not transpile cjs configs and provides correct __filename',
 	command: 'rollup -c'
-};
+});
