@@ -2,10 +2,10 @@ function toggleCase(s) {
 	return s == s.toLowerCase() ? s.toUpperCase() : s.toLowerCase();
 }
 
-module.exports = {
+module.exports = defineTest({
 	onlyWindows: true,
 	description: "can load config with cwd that doesn't match realpath",
 	command: 'rollup -c',
 	cwd: __dirname.replace(/^[a-z]:\\/i, toggleCase),
 	execute: true
-};
+});
