@@ -1,5 +1,5 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'uses config file (.mjs)',
 	command: 'rollup --config rollup.config.mjs',
 	execute: true
-};
+});
