@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'correctly generates sourcemaps for multiple outputs',
 	command: 'rollup -c --bundleConfigAsCjs'
-};
+});
