@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows plugins to set options.entry',
 	command: 'rollup -c --bundleConfigAsCjs'
-};
+});
