@@ -1,5 +1,5 @@
 module.exports = {
-	input: 'main.js',
+	input: ['main1.js', 'main2.js'],
 	output: {
 		format: 'cjs'
 	}
