@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'supports format aliases',
 	command: 'rollup --config'
-};
+});
