@@ -1,6 +1,6 @@
 const { assertIncludes } = require('../../../utils.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'overrides the generatedCode option when using presets',
 	command: 'rollup main.js --format es --generatedCode unknown',
 	error: () => true,
@@ -11,4 +11,4 @@ module.exports = {
 				'https://rollupjs.org/configuration-options/#output-generatedcode'
 		);
 	}
-};
+});
