@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'merges deprecated with current options',
 	command: 'rollup --config rollup.config.js'
-};
+});
