@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'generates multiple output files, only one of which is minified',
 	command: 'rollup -c'
-};
+});
