@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'generates multiple output files when multiple targets are specified',
 	command: 'rollup -c'
-};
+});
