@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'use no strict option',
 	command: 'rollup -i main.js -f iife --no-strict --indent'
-};
+});
