@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows paths to be set as an output option',
 	command: 'rollup --config rollup.config.js'
-};
+});
