@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles plugins where the export name is the camelized file name',
 	skipIfWindows: true,
 	command:
@@ -7,4 +7,4 @@ module.exports = {
 		'-p "./plugins/rollup-plugin-my-super-plugin2.js" ' +
 		'-p "./plugins/rollup-plugin-" ' +
 		'-p "./plugins/@rollup/plugin-supreme"'
-};
+});
