@@ -1,9 +1,9 @@
 const { assertIncludes } = require('../../../../utils.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'handles stdin errors',
 	command: `node wrapper.js`,
 	error(error) {
 		assertIncludes(error.message, 'Could not load -: Stream is broken.');
 	}
-};
+});
