@@ -1,9 +1,9 @@
 const { assertIncludes } = require('../../../utils.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'use CLI --validate to test whether output is well formed',
 	skipIfWindows: true,
-	command: `rollup main.js --silent --outro 'console.log("end"); /*' -o _actual/out.js --validate`,
+	command: `rollup main.js --outro 'console.log("end"); /*' -o _actual/out.js --validate`,
 	error: () => true,
 	stderr: stderr =>
 		assertIncludes(
@@ -15,4 +15,4 @@ out.js (3:20)
 3: console.log("end"); /*
                        ^`
 		)
-};
+});
