@@ -1,6 +1,6 @@
 const { assertIncludes } = require('../../../utils.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'warns when eval is used multiple times',
 	command: 'rollup -c',
 	stderr: stderr =>
@@ -25,4 +25,4 @@ module.exports = {
 				'\n' +
 				'...and 3 other files'
 		)
-};
+});
