@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'warns about unknown CLI options',
 	command: 'rollup --config rollup.config.js --format es --configAnswer 42 --unknownOption'
-};
+});
