@@ -4,7 +4,7 @@ const { atomicWriteFileSync } = require('../../../../utils');
 
 let mainFile;
 
-module.exports = {
+module.exports = defineTest({
 	description: 'recovers from errors during bundling',
 	command: 'rollup -cw --bundleConfigAsCjs',
 	before() {
@@ -24,4 +24,4 @@ module.exports = {
 			return true;
 		}
 	}
-};
+});
