@@ -1,6 +1,6 @@
 const { assertIncludes } = require('../../../../utils');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'does not watch if --watch is missing',
 	command: 'node wrapper.js -c --no-watch.clearScreen',
 	stderr: stderr => assertIncludes(stderr, 'main.js → _actual.js...\ncreated _actual.js in'),
@@ -9,4 +9,4 @@ module.exports = {
 			throw new Error('Watch initiated');
 		}
 	}
-};
+});
