@@ -4,7 +4,7 @@ const { atomicWriteFileSync } = require('../../../../utils');
 
 let configFile;
 
-module.exports = {
+module.exports = defineTest({
 	description: 'keeps watching the config file in case the initial file contains an error',
 	command: 'rollup -cw',
 	before() {
@@ -34,4 +34,4 @@ module.exports = {
 			return true;
 		}
 	}
-};
+});
