@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'creates different hashes if the content differs',
 	options1: {
 		input: { main: 'main1', dep: 'dep1' }
@@ -6,4 +6,4 @@ module.exports = {
 	options2: {
 		input: { main: 'main2', dep: 'dep2' }
 	}
-};
+});
