@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'creates different hashes if different variables are exported under the same name',
 	options1: {
 		input: ['main1']
@@ -6,4 +6,4 @@ module.exports = {
 	options2: {
 		input: ['main2']
 	}
-};
+});
