@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'keep extension for AMD modules',
 	options: {
 		external: ['./relative', 'abso/lute', './relative.js', 'abso/lute.js'],
 		output: { amd: { forceJsExtensionForImports: true }, interop: 'default' }
 	}
-};
+});
