@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'tracks mutations of array elements'
-};
+});
