@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not rewrite class expression IDs',
 	options: { output: { name: 'myModule' } }
-};
+});
