@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'declares updated variable in ES output (#755)',
 	options: { output: { name: 'bundle' } }
-};
+});
