@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Assignments to global variables should be effects (#1587)'
-};
+});
