@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Adds trailing semicolons for modules'
-};
+});
