@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'avoids unnecessary deoptimizations of conditional expressions'
-};
+});
