@@ -2,7 +2,7 @@ console.log('not modified');
 
 let x2 = false;
 modifyX2();
-const obj2 = {};
+const obj2 = { modified: false };
 (x2 ? obj2 : {}).modified = true;
 
 if (obj2.modified) console.log('modified');
@@ -16,7 +16,7 @@ console.log('not modified');
 
 let x4 = false;
 modifyX4();
-const obj4 = {};
+const obj4 = { modified: false };
 (x4 && obj4).modified = true;
 
 if (obj4.modified) console.log('modified');
