@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles breaking to loops inside labeled statements'
-};
+});
