@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not break flow from inside loops that may not have executed'
-};
+});
