@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Tree-shake known object prototype functions',
 	expectedWarnings: ['EMPTY_BUNDLE']
-};
+});
