@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'the parameter of a catch block should correctly shadow an import (#1391)',
 	options: { output: { name: 'bundle' } }
-};
+});
