@@ -1,7 +1,7 @@
 (function (factory) {
   typeof define === 'function' && define.amd ? define(factory) :
   factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
   var foo = function() {
     foo.toString = null;
@@ -9,4 +9,4 @@
 
   console.log(foo);
 
-})));
+}));
