@@ -1,7 +1,7 @@
 (function (factory) {
 	typeof define === 'function' && define.amd ? define(factory) :
 	factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
 	// bar.js
 	var bar = 21;
@@ -14,4 +14,4 @@
 
 	console.log( foo );
 
-})));
+}));
