@@ -1,8 +1,8 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
 	var foo = () => 'foo';
 
 	// /*
 	console.log(foo());
 
-});
+}));
