@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'correctly handles empty external imports in compact mode',
 	options: {
 		external: ['external'],
@@ -6,4 +6,4 @@ module.exports = {
 			compact: true
 		}
 	}
-};
+});
