@@ -2,4 +2,4 @@
 exports.x+=1;
 exports.x=exports.x+1;
 exports.x++;
-++exports.x;Object.defineProperty(exports,'__esModule',{value:true});}));
\ No newline at end of file
+++exports.x;}));
\ No newline at end of file
