@@ -1,11 +1,11 @@
 const retained1 = { foo: {} };
-retained1[ 'f' + 'oo' ] = globalVar;
+retained1[ 'f' + 'oo' ] = globalThis.unknown;
 retained1.foo.bar = 1;
 
 const retained2 = {};
 retained2[ 'f' + 'oo' ].bar = 1;
 
-const retained3 = { foo: globalVar };
+const retained3 = { foo: globalThis.unknown };
 retained3.foo[ 'b' + 'ar' ] = 1;
 
 const retained4 = { foo: () => {} };
