@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not add any interop when using a custom dynamic import handler',
 	options: {
 		external: 'external',
@@ -6,9 +6,10 @@ module.exports = {
 			interop: 'auto'
 		},
 		plugins: {
+			name: 'test',
 			renderDynamicImport() {
 				return { left: 'getIt(', right: ')' };
 			}
 		}
 	}
-};
+});
