@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows custom module-specific context',
 	expectedWarnings: ['THIS_IS_UNDEFINED'],
 	options: {
@@ -6,4 +6,4 @@ module.exports = {
 			'main.js': 'lolwut'
 		}
 	}
-};
+});
