@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'only deconflict "exports" for formats where it is necessary',
 	options: { output: { name: 'bundle' } }
-};
+});
