@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'prioritizes entry modules over dependencies when deconflicting'
-};
+});
