@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not consider nested tree-shaken variables when deconflicting'
-};
+});
