@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not deconflict due to tree-shaken global variables'
-};
+});
