@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'dedupes external imports',
 	options: {
 		external: ['external'],
@@ -7,4 +7,4 @@ module.exports = {
 			name: 'myBundle'
 		}
 	}
-};
+});
