@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles deeply nested properties',
 	options: {
 		treeshake: { propertyReadSideEffects: false }
 	}
-};
+});
