@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles hoisted declarations in deeply nested switch statements'
-};
+});
