@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows specifying the export mode to be "default"',
 	options: {
 		output: {
@@ -6,4 +6,4 @@ module.exports = {
 			name: 'bundle'
 		}
 	}
-};
+});
