@@ -1,7 +1,7 @@
 (function (factory) {
   typeof define === 'function' && define.amd ? define(factory) :
   factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
   function a() {
     a = someGlobal;
@@ -10,4 +10,4 @@
 
   a();
 
-})));
+}));
