@@ -1,8 +1,8 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'amd.define',
 	options: {
 		output: {
 			amd: { define: 'enifed' }
 		}
 	}
-};
+});
