@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deoptimizes typeof for regular expressions to better support es6-sim'
-};
+});
