@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not deoptimize the entire superclass when reassigning a property'
-};
+});
