@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deoptimizes var variables in hoisted scopes'
-};
+});
