@@ -1,8 +1,8 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'dynamic import inlining',
 	options: {
 		strictDeprecations: false,
 		inlineDynamicImports: true
 	},
 	expectedWarnings: ['DEPRECATED_FEATURE']
-};
+});
