@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not remove duplicated var declarations (#716)'
-};
+});
