@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'uses correct "this" in dynamic imports when using arrow functions',
 	options: {
 		external: ['input', 'output'],
@@ -8,4 +8,4 @@ module.exports = {
 			dynamicImportInCjs: false
 		}
 	}
-};
+});
