@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'correctly resolves namespace members when accessed early (#2895)',
 	options: { external: 'external' }
-};
+});
