@@ -1,6 +1,6 @@
 'use strict';
 
-const items = [{}, {}, {}];
+const items = { children: [ {}, {}, {} ] };
 
 function a () {
 	for ( const item of items.children ) {
@@ -23,4 +23,4 @@ assert.deepEqual( items, [
 	{ foo: 'a', bar: 'c' },
 	{ foo: 'a', bar: 'c' },
 	{ foo: 'a', bar: 'c' }
-]);
+] );
