@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'includes effects in for-of loop (#870)'
-};
+});
