@@ -1,10 +1,11 @@
 const { readFileSync } = require('node:fs');
 const path = require('node:path');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'does not include format globals when tree-shaking an asset access',
 	options: {
 		plugins: {
+			name: 'test',
 			resolveId(id, importee) {
 				if (id.endsWith('.svg')) {
 					return path.resolve(path.dirname(importee), id);
@@ -21,4 +22,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
