@@ -1,8 +1,8 @@
 (function (factory) {
 	typeof define === 'function' && define.amd ? define(factory) :
 	factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
 	console.log( 1 );console.log( 2 );
 
-})));
+}));
