@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'removes an empty try-catch-finally statement'
-};
+});
