@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'erroneous nested member expression does not mess up naming'
-};
+});
