@@ -1,7 +1,7 @@
-System.register([], function () {
+System.register([], (function () {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			function yar() {
 				return {
@@ -13,6 +13,6 @@ System.register([], function () {
 
 			yar.har();
 
-		}
+		})
 	};
-});
+}));
