@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'statements that modify definitions within unused functions are excluded'
-};
+});
