@@ -1,7 +1,7 @@
-System.register([], function () {
+System.register([], (function () {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			var foo = {};
 
@@ -28,6 +28,6 @@ System.register([], function () {
 
 			console.log( foo );
 
-		}
+		})
 	};
-});
+}));
