@@ -1,7 +1,7 @@
 (function (factory) {
 	typeof define === 'function' && define.amd ? define(factory) :
 	factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
 	var foo = {};
 
@@ -28,4 +28,4 @@
 
 	console.log( foo );
 
-})));
+}));
