@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'folds exponentiation operator when considering dead code'
-};
+});
