@@ -6,7 +6,7 @@ define(['exports', 'external'], (function (exports, external) { 'use strict';
 
 	exports.internalFn = internalFn;
 	Object.keys(external).forEach(function (k) {
-		if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
+		if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
 			enumerable: true,
 			get: function () { return external[k]; }
 		});
