@@ -2,7 +2,7 @@ System.register('exposedInternals', ['external'], (function (exports) {
 	'use strict';
 	var _starExcludes = {
 		internalFn: 1,
-		'default': 1
+		default: 1
 	};
 	return {
 		setters: [function (module) {
