@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'should be able to export * from the bundle',
 	options: { output: { name: 'exposedInternals' } }
-};
+});
