@@ -2,10 +2,10 @@
 	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
 	typeof define === 'function' && define.amd ? define(factory) :
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.myBundle = factory());
-}(this, (function () { 'use strict';
+})(this, (function () { 'use strict';
 
 	var bar = 1;
 
 	return bar;
 
-})));
+}));
