@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'single default export in deep namespace',
 	options: { output: { name: 'my.global.namespace' } }
-};
+});
