@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles default exporting global variables',
 	options: { output: { name: 'bundle' } }
-};
+});
