@@ -1,12 +1,12 @@
-System.register('bundle', [], function (exports) {
+System.register('bundle', [], (function (exports) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			var value = exports('default', global);
 
 			console.log(value);
 
-		}
+		})
 	};
-});
+}));
