@@ -2,7 +2,7 @@ System.register('myBundle', ['x'], (function (exports) {
 	'use strict';
 	return {
 		setters: [function (module) {
-			exports('x', module["default"]);
+			exports('x', module.default);
 		}],
 		execute: (function () {
 
