@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'single (default) exports',
 	options: { output: { name: 'myBundle' } }
-};
+});
