@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'supports exporting and resolving internal namespaces as names'
-};
+});
