@@ -1,8 +1,8 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'exported live bindings',
 	options: {
 		output: {
 			name: 'iife'
 		}
 	}
-};
+});
