@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'splits up multiple vars in a single export declaration'
-};
+});
