@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'supports exporting namespaces as names in entry points',
 	options: { output: { name: 'bundle' } }
-};
+});
