@@ -3,8 +3,8 @@ const bar = 'bar1';
 
 var dep = /*#__PURE__*/Object.freeze({
 	__proto__: null,
-	foo: foo,
-	bar: bar
+	bar: bar,
+	foo: foo
 });
 
 export { dep };
