@@ -8,8 +8,8 @@ System.register('bundle', [], (function (exports) {
 
 			var dep = /*#__PURE__*/Object.freeze({
 				__proto__: null,
-				foo: foo,
-				bar: bar
+				bar: bar,
+				foo: foo
 			});
 			exports('dep', dep);
 
