@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'exports variables at end, if possible',
 	options: { output: { name: 'myBundle' } }
-};
+});
