@@ -1,12 +1,12 @@
 import { Test as Test$1 } from 'a';
-import Test$1$1 from 'b';
+import Test$2 from 'b';
 
 const Test = () => {
   console.log(Test$1);
 };
 
 const Test1 = () => {
-  console.log(Test$1$1);
+  console.log(Test$2);
 };
 
 export { Test, Test1 };
