@@ -2,7 +2,7 @@ System.register('myBundle', ['babel-polyfill', 'other'], (function (exports) {
 	'use strict';
 	var x;
 	return {
-		setters: [function () {}, function (module) {
+		setters: [null, function (module) {
 			x = module.x;
 		}],
 		execute: (function () {
