@@ -1,13 +1,13 @@
-System.register('myBundle', ['external'], function (exports) {
+System.register('myBundle', ['external'], (function (exports) {
 	'use strict';
 	return {
 		setters: [function (module) {
 			exports('s', module.p);
 		}],
-		execute: function () {
+		execute: (function () {
 
 
 
-		}
+		})
 	};
-});
+}));
