@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows global names to be specified for IIFE/UMD exports',
 	options: {
 		external: ['jquery'],
 		output: { globals: { jquery: 'jQuery' } }
 	}
-};
+});
