@@ -4,8 +4,7 @@
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.foo));
 })(this, (function (foo) { 'use strict';
 
-	function _interopNamespace(e) {
-		if (e && e.__esModule) return e;
+	function _interopNamespaceDefault(e) {
 		var n = Object.create(null);
 		if (e) {
 			Object.keys(e).forEach(function (k) {
@@ -18,11 +17,11 @@
 				}
 			});
 		}
-		n["default"] = e;
+		n.default = e;
 		return Object.freeze(n);
 	}
 
-	var foo__namespace = /*#__PURE__*/_interopNamespace(foo);
+	var foo__namespace = /*#__PURE__*/_interopNamespaceDefault(foo);
 
 	console.log(foo__namespace);
 	console.log(foo.blah);
