@@ -17,4 +17,4 @@ for ( const foo in { x: effect3() } ) {
 	let effect3 = () => {}; // This can be removed
 }
 
-for ( globalVar in { x: 1 } ) {}
+for ( globalThis.unknown in { x: 1 } ) {}
