@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'use a newline for line wraps removing a necessary semicolon (#1275)'
-};
+});
