@@ -1,5 +1,5 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
 	for(var x=1;x<2;x++)var d=x|0;console.log(d);
 
-});
+}));
