@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles for loop with empty head'
-};
+});
