@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'properly associate or shadow variables in and around for-of-loops'
-};
+});
