@@ -5,8 +5,8 @@ define(['exports'], (function (exports) { 'use strict';
 
 	var namespace = {
 		__proto__: null,
-		foo: foo,
-		bar: bar
+		bar: bar,
+		foo: foo
 	};
 
 	console.log( Object.keys( namespace ) );
