@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'properly extract return values from function bodies'
-};
+});
