@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'function-mutations do not have effects',
 	options: { output: { name: 'bundle' } }
-};
+});
