@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'uses block bindings',
 	expectedWarnings: ['SHIMMED_EXPORT'],
 	options: {
@@ -14,6 +14,7 @@ module.exports = {
 		},
 		plugins: [
 			{
+				name: 'test',
 				transform(code, id) {
 					if (id.endsWith('synthetic.js')) {
 						return { syntheticNamedExports: true };
@@ -22,4 +23,4 @@ module.exports = {
 			}
 		]
 	}
-};
+});
