@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'handles generatedCode preset "es5"',
 	options: {
 		output: {
@@ -11,6 +11,7 @@ module.exports = {
 		},
 		plugins: [
 			{
+				name: 'test',
 				renderStart(options) {
 					assert.strictEqual(options.generatedCode.arrowFunctions, false);
 					assert.strictEqual(options.generatedCode.objectShorthand, false);
@@ -19,4 +20,4 @@ module.exports = {
 			}
 		]
 	}
-};
+});
