@@ -4,9 +4,9 @@
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.ns));
 })(this, (function (ns) { 'use strict';
 
-	function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e["default"] : e; }
+	function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e["default"] : e; }
 
-	var ns__default = /*#__PURE__*/_interopDefaultLegacy(ns);
+	var ns__default = /*#__PURE__*/_interopDefaultCompat(ns);
 
 	console.log(ns__default);
 
