@@ -31,10 +31,10 @@ System.register('bundle', ['external', 'externalDefaultOnly', 'external2'], (fun
 				foo: 'bar'
 			};
 
-			var ns = /*#__PURE__*/Object.freeze(/*#__PURE__*/_mergeNamespaces({
+			var ns = /*#__PURE__*/_mergeNamespaces({
 				__proto__: null,
 				'default': other
-			}, [other]));
+			}, [other]);
 
 			console.log(ns, other.foo, other["function"], other["some-prop"], function$1, someDefault, defaultOnly);
 			console.log(module.meta["function"], module.meta["some-prop"]);
