@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'forwards return values of getters'
-};
+});
