@@ -1,9 +1,9 @@
 (function (factory) {
 	typeof define === 'function' && define.amd ? define(factory) :
 	factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
 	Unknown.staticMember;
 	Unknown.prototype.method;
 
-})));
+}));
