@@ -4,10 +4,6 @@
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.unchanged, global.changedName, global.specialCharacter, global.slash, global.relative_js));
 })(this, (function (unchanged, changedName, specialCharacter, slash, relative_js) { 'use strict';
 
-	function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }
-
-	var changedName__default = /*#__PURE__*/_interopDefaultLegacy(changedName);
-
-	console.log(unchanged.foo, changedName__default["default"], specialCharacter.bar, slash.baz, relative_js.quux);
+	console.log(unchanged.foo, changedName, specialCharacter.bar, slash.baz, relative_js.quux);
 
 }));
