@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'Properly renders branches which refer to hoisted variables from other lexical scopes'
-};
+});
