@@ -1,7 +1,7 @@
-System.register([], function () {
+System.register([], (function () {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			let a;
 			a();
@@ -15,6 +15,6 @@ System.register([], function () {
 			let { d } = {};
 			d.foo = 'bar';
 
-		}
+		})
 	};
-});
+}));
