@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'keeps any import assertions on input',
-	expectedWarnings: 'UNRESOLVED_IMPORT',
+	expectedWarnings: ['UNRESOLVED_IMPORT'],
 	options: {
 		external: id => {
 			if (id === 'unresolved') return null;
@@ -8,4 +8,4 @@ module.exports = {
 		},
 		output: { name: 'bundle' }
 	}
-};
+});
