@@ -32,7 +32,7 @@ Object.defineProperty(exports, 'c', {
 	get: function () { return c.c; }
 });
 Object.keys(d$1).forEach(function (k) {
-	if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
+	if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
 		enumerable: true,
 		get: function () { return d$1[k]; }
 	});
