@@ -4,10 +4,7 @@
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.foo));
 })(this, (function (foo) { 'use strict';
 
-	function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }
-
-	function _interopNamespace(e) {
-		if (e && e.__esModule) return e;
+	function _interopNamespaceDefault(e) {
 		var n = Object.create(null);
 		if (e) {
 			Object.keys(e).forEach(function (k) {
@@ -20,15 +17,14 @@
 				}
 			});
 		}
-		n["default"] = e;
+		n.default = e;
 		return Object.freeze(n);
 	}
 
-	var foo__namespace = /*#__PURE__*/_interopNamespace(foo);
-	var foo__default = /*#__PURE__*/_interopDefaultLegacy(foo);
+	var foo__namespace = /*#__PURE__*/_interopNamespaceDefault(foo);
 
 	console.log( foo__namespace.bar );
 
-	console.log( foo__default["default"] );
+	console.log( foo );
 
 }));
