@@ -1,5 +1,5 @@
-define(['module'], function (module) { 'use strict';
+define(['module'], (function (module) { 'use strict';
 
 	console.log(({ url: new URL(module.uri, document.baseURI).href }));
 
-});
+}));
