@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'completely removes tree-shaken dynamic imports ',
 	options: {
 		output: { inlineDynamicImports: true }
 	}
-};
+});
