@@ -1,8 +1,9 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows to configure the interop type per external dependency',
 	options: {
 		external: id => id.startsWith('external'),
 		output: {
+			/** @type any*/
 			interop(id) {
 				if (id === null) {
 					return 'auto';
@@ -15,4 +16,4 @@ module.exports = {
 			dynamicImportInCjs: false
 		}
 	}
-};
+});
