@@ -1,8 +1,9 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows to configure the interop type per reexported external dependency',
 	options: {
 		external: id => id.startsWith('external'),
 		output: {
+			/** @type any */
 			interop(id) {
 				return id.split('-')[1];
 			},
@@ -12,4 +13,4 @@ module.exports = {
 			name: 'bundle'
 		}
 	}
-};
+});
