@@ -15,7 +15,7 @@ console.log( b );
 
 var main = 42;
 
-export default main;
+export { main as default };
 
 /* this is an outro */
 
