@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'Does not fail when bundling code where the `in`-operator is used with invalid right sides'
-};
+});
