@@ -1,7 +1,7 @@
-System.register('myBundle', [], function (exports) {
+System.register('myBundle', [], (function (exports) {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			var main = exports('default', (input) => {
 				try {
@@ -12,6 +12,6 @@ System.register('myBundle', [], function (exports) {
 				}
 			});
 
-		}
+		})
 	};
-});
+}));
