@@ -2,7 +2,7 @@
 	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
 	typeof define === 'function' && define.amd ? define(factory) :
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.myBundle = factory());
-}(this, (function () { 'use strict';
+})(this, (function () { 'use strict';
 
 	var main = (input) => {
 		try {
@@ -15,4 +15,4 @@
 
 	return main;
 
-})));
+}));
