@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'always keep leading comments when tree-shaking and no automatic semicolons are inserted'
-};
+});
