@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not consider it a side-effect if a known global variable is accessed'
-};
+});
