@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'keep break statements if their label is included'
-};
+});
