@@ -1,3 +1,3 @@
-var x = "0";
+var x = "$";
 
-export var result = `64 = ${x}`;
\ No newline at end of file
+export var result = `64 = ${x}`;
