@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'tracks literal values across return expressions'
-};
+});
