@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles deoptimizations of logical expression while they are inlcuded (#3324)'
-};
+});
