@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'properly handle the results of mutating logical expressions',
 	options: { output: { name: 'bundle' } }
-};
+});
