@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'simplifies logical expressions that resolve statically to non-boolean values'
-};
+});
