@@ -3,7 +3,7 @@ const path = require('node:path');
 
 const ID_MAIN = path.join(__dirname, 'main.js');
 
-module.exports = {
+module.exports = defineTest({
 	description:
 		'only normalizes external paths that were originally relative when set to "ifRelativeSource"',
 	options: {
@@ -22,6 +22,7 @@ module.exports = {
 				return true;
 		},
 		plugins: {
+			name: 'test',
 			async buildStart() {
 				// eslint-disable-next-line unicorn/consistent-function-scoping
 				const testExternal = async (source, expected) =>
@@ -49,4 +50,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
