@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'inserts semicolons correctly when modifying SystemJS exports',
 	formats: ['system']
-};
+});
