@@ -1,4 +1,4 @@
 var foo = 1;
 var bar = 2;
 
-export { foo, bar };
+export { bar, foo };
