@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles interacting with missing namespace members',
 	expectedWarnings: ['MISSING_EXPORT']
-};
+});
