@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'properly encodes reserved names if namespace import is used',
 	options: {
 		input: ['main.js']
 	}
-};
+});
