@@ -5,7 +5,7 @@
 
 	var dep$1 = /*#__PURE__*/Object.freeze({
 		__proto__: null,
-		'default': dep
+		default: dep
 	});
 
 	console.log(dep$1);
