@@ -1,4 +1,4 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
 	function a () {
 		console.log('effect');
@@ -6,4 +6,4 @@ define(function () { 'use strict';
 
 	a();
 
-});
+}));
