@@ -10,7 +10,7 @@ Object.defineProperty(exports, 'renamedDirectOverride', {
 });
 exports.renamedIndirectOverride = renamedIndirectOverride;
 Object.keys(external).forEach(function (k) {
-	if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
+	if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
 		enumerable: true,
 		get: function () { return external[k]; }
 	});
