@@ -1,5 +1,4 @@
-import { indirectOverride, ignoredOverride } from './external-reexport';
+import { indirectOverride } from './external-reexport';
 export { directOverride as renamedDirectOverride } from './external-reexport';
 
 export const renamedIndirectOverride = indirectOverride;
-export const conflictOverride = ignoredOverride;
