@@ -3,5 +3,7 @@
 Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });
 
 const foo = 42;
+var main = 43;
 
+exports.default = main;
 exports.foo = foo;
