@@ -8,8 +8,8 @@ System.register('myBundle', [], (function (exports) {
 
 			var namespace = /*#__PURE__*/Object.freeze({
 				__proto__: null,
-				foo: foo,
-				bar: bar
+				bar: bar,
+				foo: foo
 			});
 
 			console.log( Object.keys( namespace ) );
