@@ -9,8 +9,8 @@
 
 	var namespace = /*#__PURE__*/Object.freeze({
 		__proto__: null,
-		foo: foo,
-		bar: bar
+		bar: bar,
+		foo: foo
 	});
 
 	console.log( Object.keys( namespace ) );
