@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deconflicts variables when nested dynamic imports are inlined',
 	options: {
 		output: { inlineDynamicImports: true }
 	}
-};
+});
