@@ -1,7 +1,7 @@
 (function (factory) {
 	typeof define === 'function' && define.amd ? define(factory) :
 	factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
 	async function main() {
 		const foo$1 = 1;
@@ -18,4 +18,4 @@
 		value: value
 	});
 
-})));
+}));
