@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'throw an error when accessing members of null or undefined'
-};
+});
