@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'supports the new.target meta property'
-};
+});
