@@ -6,7 +6,7 @@ var bundle = (function (exports, external1, external2) {
 	exports.external1 = external1.external1;
 	exports.dynamic = dynamic;
 	Object.keys(external2).forEach(function (k) {
-		if (k !== 'default' && !exports.hasOwnProperty(k)) exports[k] = external2[k];
+		if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) exports[k] = external2[k];
 	});
 
 	return exports;
