@@ -1,11 +1,11 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
-	const other = {
+	const other$1 = {
 		something: 'here'
 	};
 
-	const other$1 = {
+	const other = {
 		somethingElse: 'here'
 	};
 
-});
+}));
