@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'generates namespace objects when not tree-shaking',
 	options: {
 		treeshake: false
 	}
-};
+});
