@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'do not remove non an empty block statement'
-};
+});
