@@ -50,9 +50,9 @@
 
 	var reexportExternalsWithOverride$1 = /*#__PURE__*/_mergeNamespaces({
 		__proto__: null,
-		override: override,
 		default: reexportExternalsWithOverride,
-		extra: extra
+		extra: extra,
+		override: override
 	}, [reexportExternalsWithOverride, external1__namespace, external2__namespace]);
 
 	exports.external = reexportExternal;
