@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Associates non-string keys with string keys'
-};
+});
