@@ -1,24 +1,17 @@
-const x = {
-	[globalThis.unknown]() {
-		console.log('effect');
-	},
-	a() {}
-};
-
-x.a();
-
 const y = {
 	a() {},
+	b: () => {},
 	[globalThis.unknown]() {
 		console.log('effect');
 	}
 };
 
 y.a();
+y.b();
 
 const z = {
 	[globalThis.unknown]() {}
 };
 
 z.a();
-z.hasOwnProperty('a'); // removed
+z.hasOwnProperty('a');
