@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'uses an unknown value for nested properties',
 	options: {
 		treeshake: { propertyReadSideEffects: false }
 	}
-};
+});
