@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Deoptimize when __proto__ is used'
-};
+});
