@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Track side-effects of method return values'
-};
+});
