@@ -1,5 +1,5 @@
 const x = {
-	[unknown]: () => () => console.log('effect'),
+	[globalThis.unknown]: () => () => console.log('effect'),
 	a: () => () => {}
 };
 
@@ -7,13 +7,13 @@ x.a()();
 
 const y = {
 	a: () => () => {},
-	[unknown]: () => () => console.log('effect')
+	[globalThis.unknown]: () => () => console.log('effect')
 };
 
 y.a()();
 
 const z = {
-	[unknown]: () => ({})
+	[globalThis.unknown]: () => ({})
 };
 
 z.a()();
