@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'removes unknown getter access without side effect',
 	options: { external: ['external'] }
-};
+});
