@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'detect side-effects in overwritten properties of object literals'
-};
+});
