@@ -11,7 +11,7 @@ exports.a = a;
 exports.c = c;
 exports.reassign = reassign;
 Object.keys(external).forEach(function (k) {
-	if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
+	if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
 		enumerable: true,
 		get: function () { return external[k]; }
 	});
