@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Make sure side-effects are passed along destructuring assignments',
 	options: { output: { name: 'bundle' } }
-};
+});
