@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles member expressions in patterns (#2750)'
-};
+});
