@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Preserves asm.js code (#3360)'
-};
+});
