@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'debugger statements are preserved (#664)'
-};
+});
