@@ -1,10 +1,10 @@
 (function (factory) {
 	typeof define === 'function' && define.amd ? define(factory) :
 	factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
 	before();
 	debugger;
 	after();
 
-})));
+}));
