@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'respects access side-effects when calling a getter'
-};
+});
