@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles accessing the return expression of a getter before it has been bound'
-};
+});
