@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'prunes pure unused external imports ([#1352])',
 	expectedWarnings: ['EMPTY_BUNDLE'],
 	options: {
@@ -8,4 +8,4 @@ module.exports = {
 			globals: { other: 'other' }
 		}
 	}
-};
+});
