@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'adjust line-break handling when dealing with pure annotations'
-};
+});
