@@ -24,9 +24,9 @@ console.log('should remain impure');
 console.log('code');
 console.log('should remain impure');
 
- console.log('should remain impure');
+console.log('should remain impure');
 
- console.log('should remain impure') ;
+console.log('should remain impure') ;
 
 console.log('code');
 console.log('should remain impure', x);
@@ -35,3 +35,16 @@ console.log('should remain impure', x);
 {
 	console.log('should remain impure');
 }
+keep1()  ; keep2();
+keep3() ; 
+keep4()  ; /* other comment */ keep5();
+keep6()  ; // other comment
+keep7();
+keep8()  && keep9();
+
+ Keep1()  , Keep2(),
+Keep3() , 
+Keep4()  , /* other comment */ Keep5(),
+Keep6()  , // other comment
+Keep7(),
+Keep8()  && Keep9();
