@@ -3,4 +3,4 @@
 
 	console.log(quoted_____external1.foo, quoted_____external2.bar, Path_js.baz);
 
-}(quotedExternal1, quotedExternal2, quotedExternal3));
+})(quotedExternal1, quotedExternal2, quotedExternal3);
