@@ -1,14 +1,14 @@
 (function (global, factory) {
 	typeof exports === 'object' && typeof module !== 'undefined' ? factory(require('quoted\'\
 \
-\ \ external1'), require('./quoted\'\
+\ \ external1'), require('quoted\'\
 \
-\ \ external2'), require('./C:/File/Path.js')) :
+\ \ external2'), require('C:\\File\\Path.js')) :
 	typeof define === 'function' && define.amd ? define(['quoted\'\
 \
-\ \ external1', './quoted\'\
+\ \ external1', 'quoted\'\
 \
-\ \ external2', './C:/File/Path'], factory) :
+\ \ external2', 'C:\\File\\Path.js'], factory) :
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.quotedExternal1, global.quotedExternal2, global.quotedExternal3));
 })(this, (function (quoted_____external1, quoted_____external2, Path_js) { 'use strict';
 
