@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'use legal names for exported functions and classed (#1943)',
 	options: { output: { name: 'bundle' } }
-};
+});
