@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'do not fail for literal values from recursive return values'
-};
+});
