@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handle recursive reassignments of return values'
-};
+});
