@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'make sure re-declarations via var and function are linked properly'
-};
+});
