@@ -2,7 +2,7 @@ System.register('bundle', ['external'], (function (exports) {
 	'use strict';
 	return {
 		setters: [function (module) {
-			exports('default', module["default"]);
+			exports('default', module.default);
 		}],
 		execute: (function () {
 
