@@ -4,12 +4,8 @@
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.bundle = factory(global.external1, global.external2));
 })(this, (function (external1, external2) { 'use strict';
 
-	function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }
-
-	var external2__default = /*#__PURE__*/_interopDefaultLegacy(external2);
-
 	console.log(external1.foo);
 
-	return external2__default["default"];
+	return external2;
 
 }));
