@@ -2,8 +2,8 @@
 	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('external')) :
 	typeof define === 'function' && define.amd ? define(['external'], factory) :
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.bundle = factory(global.external));
-}(this, (function (external) { 'use strict';
+})(this, (function (external) { 'use strict';
 
 	return external.value;
 
-})));
+}));
