@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles recursions when a module reexports its own namespace',
 	expectedWarnings: ['CIRCULAR_DEPENDENCY']
-};
+});
