@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Also remove banner comments when completely tree-shaking files'
-};
+});
