@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles deconflicting of variables used as defaults in patterns (#2445)'
-};
+});
