@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'renders named export declarations',
 	options: { output: { name: 'bundle' } }
-};
+});
