@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'make sure removed statements do no leave unwanted white-space'
-};
+});
