@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not depend on the resolution order of modules for tree-shaking (#2753)',
 	options: {
 		plugins: {
@@ -9,4 +9,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
