@@ -6,9 +6,9 @@
 	console.log('resolved');
 	console.log('resolved');
 
-	console.log((_documentCurrentScript && _documentCurrentScript.src || new URL('iife.js', document.baseURI).href));
+	console.log((_documentCurrentScript && _documentCurrentScript.tagName.toUpperCase() === 'SCRIPT' && _documentCurrentScript.src || new URL('iife.js', document.baseURI).href));
 	console.log(undefined);
-	console.log(({ url: (_documentCurrentScript && _documentCurrentScript.src || new URL('iife.js', document.baseURI).href) }));
+	console.log(({ url: (_documentCurrentScript && _documentCurrentScript.tagName.toUpperCase() === 'SCRIPT' && _documentCurrentScript.src || new URL('iife.js', document.baseURI).href) }));
 
 	console.log('url=iife.js:resolve-import-meta-url/main.js');
 	console.log('privateProp=iife.js:resolve-import-meta-url/main.js');
