@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'tree-shakes entities referenced in a return statement after an error'
-};
+});
