@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles accessing funciton return values in deoptimized conditionals'
-};
+});
