@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles situations where a member expression is deoptimized while being deoptimized'
-};
+});
