@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'only retain expressions with effects in sequence expressions (#1649)'
-};
+});
