@@ -1,10 +1,10 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
-	function x () {
+	function x$2 () {
 		return 'foo';
 	}
 
-	var foo = { x };
+	var foo = { x: x$2 };
 
 	function x$1 () {
 		return 'bar';
@@ -12,14 +12,14 @@ define(function () { 'use strict';
 
 	var bar = { x: x$1 };
 
-	function x$2 () {
+	function x () {
 		return 'baz';
 	}
 
-	var baz = { x: x$2 };
+	var baz = { x };
 
 	assert.equal( foo.x(), 'foo' );
 	assert.equal( bar.x(), 'bar' );
 	assert.equal( baz.x(), 'baz' );
 
-});
+}));
