@@ -1,13 +1,13 @@
-System.register([], function () {
+System.register([], (function () {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
-			function x () {
+			function x$2 () {
 				return 'foo';
 			}
 
-			var foo = { x };
+			var foo = { x: x$2 };
 
 			function x$1 () {
 				return 'bar';
@@ -15,16 +15,16 @@ System.register([], function () {
 
 			var bar = { x: x$1 };
 
-			function x$2 () {
+			function x () {
 				return 'baz';
 			}
 
-			var baz = { x: x$2 };
+			var baz = { x };
 
 			assert.equal( foo.x(), 'foo' );
 			assert.equal( bar.x(), 'bar' );
 			assert.equal( baz.x(), 'baz' );
 
-		}
+		})
 	};
-});
+}));
