@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'Observes side-effects in side-effect-free modules that contain a used default export that just reexports from another module',
 	options: {
 		treeshake: { moduleSideEffects: false }
 	}
-};
+});
