@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'includes top-level throw statements',
 	options: { output: { name: 'myBundle' } }
-};
+});
