@@ -4,4 +4,4 @@ if ( !ok ) {
 
 var main = 42;
 
-export default main;
+export { main as default };
