@@ -2,7 +2,7 @@
 	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
 	typeof define === 'function' && define.amd ? define(factory) :
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.myBundle = factory());
-}(this, (function () { 'use strict';
+})(this, (function () { 'use strict';
 
 	if ( !ok ) {
 		throw new Error( 'this will be included' );
@@ -12,4 +12,4 @@
 
 	return main;
 
-})));
+}));
