@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'use of arguments is treated as a side-effect',
 	options: { output: { name: 'myBundle' } }
-};
+});
