@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'detects side-effects in circular function calls',
 	expectedWarnings: ['CIRCULAR_DEPENDENCY']
-};
+});
