@@ -1,9 +1,7 @@
 'use strict';
 
-var bool = true;
-
 const hs = document.documentElement.style;
 
-if ( bool ) {
+{
 	hs.color = "#222";
 }
