@@ -1,7 +1,5 @@
-var bool = true;
-
 const hs = document.documentElement.style;
 
-if ( bool ) {
+{
 	hs.color = "#222";
 }
