@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'throw statement is a side effect',
 	options: { output: { name: 'myBundle' } }
-};
+});
