@@ -1,7 +1,7 @@
 (function (factory) {
 	typeof define === 'function' && define.amd ? define(factory) :
 	factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
 	function foo () {
 		throw new Error( 'throw side effect' );
@@ -9,4 +9,4 @@
 
 	foo();
 
-})));
+}));
