@@ -1,6 +1,6 @@
 var x = {foo: 'bar'};
 delete x.foo;
 
-delete globalVariable.foo;
+delete globalThis.unknown.foo;
 
 export { x };
