@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'determine side effects in ES6 super classes'
-};
+});
