@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Properly detect side-effects in generator functions'
-};
+});
