@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'treat getters and setters as function calls'
-};
+});
