@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'detects side-effects in template literals and tagged template expressions',
 	options: { output: { name: 'myBundle' } }
-};
+});
