@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'only evaluate the second part of a logical expression if necessary'
-};
+});
