@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'side-effects when mutating destructured variables should not be ignored'
-};
+});
