@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'side-effects in pattern defaults should not be ignored'
-};
+});
