@@ -1,4 +1,4 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
 	function isUsed ( x ) {
 		if ( x ) {
@@ -9,4 +9,4 @@ define(function () { 'use strict';
 
 	assert.equal( isUsed( true ), 2 );
 
-});
+}));
