@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allow calls to pure static methods to be tree-shaken'
-};
+});
