@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles slashes in function parameters and correctly inserts missing ids'
-};
+});
