@@ -1,7 +1,7 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'correct sourcemaps are written (inline)',
 	skipIfWindows: true,
 	options: {
 		output: { sourcemap: 'inline' }
 	}
-};
+});
