@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'avoids infinite recursions when deoptimizing "this" context'
-};
+});
