@@ -1,8 +1,8 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'use strict should not be present',
 	options: {
 		output: {
 			strict: false
 		}
 	}
-};
+});
