@@ -1,7 +1,7 @@
 'use strict';
 
-var a = 'a';
-var b = 'b';
+var a = 'a',
+    b = 'b';
 
 assert.equal( a, 'a' );
 assert.equal( b, 'b' );
