@@ -1,5 +1,5 @@
-var a = 'a';
-var b = 'b';
+var a = 'a',
+    b = 'b';
 
 assert.equal( a, 'a' );
 assert.equal( b, 'b' );
