@@ -1,7 +1,7 @@
 (function (factory) {
     typeof define === 'function' && define.amd ? define(factory) :
     factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
     var a = 'a',
         b = 'b';
@@ -9,4 +9,4 @@
     assert.equal( a, 'a' );
     assert.equal( b, 'b' );
 
-})));
+}));
