@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'does not assume string.replace has side effects when called with a string as second argument'
-};
+});
