@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'correctly resolves the prototype of the super class when accessing properties'
-};
+});
