@@ -6,6 +6,4 @@ class Access extends SuperAccess {}
 
 Access.prototype.doesNoExist;
 Access.prototype.doesNoExist.throws;
-Access.prototype.method.doesNoExist;
-Access.prototype.method.doesNoExist.throws;
 Access.prototype.prop.throws;
