@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'supports core-js',
 	options: {
 		// check against tree-shake: false when updating the polyfill
@@ -8,4 +8,4 @@ module.exports = {
 			require('@rollup/plugin-commonjs')()
 		]
 	}
-};
+});
