@@ -1,8 +1,8 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Renders updates of exported variables for SystemJS output',
 	options: {
 		output: {
 			format: 'system'
 		}
 	}
-};
+});
