@@ -1,12 +1,12 @@
-System.register([], function (exports) {
+System.register([], (function (exports) {
   'use strict';
   return {
-    execute: function () {
+    execute: (function () {
 
       var main = exports('default', typeof global !== "undefined" ? global :
         typeof self !== "undefined" ? self :
         typeof window !== "undefined" ? window : {});
 
-    }
+    })
   };
-});
+}));
