@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Resolve template literals in computed property keys'
-};
+});
