@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Template literals can be simplified when used in conditionals'
-};
+});
