@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'uses the correct "this" value in class properties'
-};
+});
