@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'tracks tree-shaking of arguments through simplified conditionals'
-};
+});
