@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Remove side-effect-free curried functions (#1263)',
 	expectedWarnings: ['EMPTY_BUNDLE']
-};
+});
