@@ -1,7 +1,7 @@
 (function (factory) {
 	typeof define === 'function' && define.amd ? define(factory) :
 	factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
 	/* header 3 */
 
@@ -57,4 +57,4 @@
 	importedUsedFunction();
 	usedNamedFunction();
 
-})));
+}));
