@@ -1,10 +1,10 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
 	function getStringA() {
 		return 'A';
 	}
 
-	console.log( getStringA());
+	console.log(getStringA());
 
 	console.log(false );
 
@@ -14,6 +14,6 @@ define(function () { 'use strict';
 		return 'D';
 	}
 
-	console.log( getStringD());
+	console.log(getStringD());
 
-});
+}));
