@@ -1,13 +1,13 @@
-System.register([], function () {
+System.register([], (function () {
 	'use strict';
 	return {
-		execute: function () {
+		execute: (function () {
 
 			function getStringA() {
 				return 'A';
 			}
 
-			console.log( getStringA());
+			console.log(getStringA());
 
 			console.log(false );
 
@@ -17,8 +17,8 @@ System.register([], function () {
 				return 'D';
 			}
 
-			console.log( getStringD());
+			console.log(getStringD());
 
-		}
+		})
 	};
-});
+}));
