@@ -1,13 +1,13 @@
 (function (factory) {
 	typeof define === 'function' && define.amd ? define(factory) :
 	factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
 	function getStringA() {
 		return 'A';
 	}
 
-	console.log( getStringA());
+	console.log(getStringA());
 
 	console.log(false );
 
@@ -17,6 +17,6 @@
 		return 'D';
 	}
 
-	console.log( getStringD());
+	console.log(getStringD());
 
-})));
+}));
