@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'tree-shake pure call expressions involving optional chaining'
-};
+});
