@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'removes unneeded arguments across namespace member calls'
-};
+});
