@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not remove arguments from calls when rest parameters are used'
-};
+});
