@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'removes arguments that correspond to unused parameters'
-};
+});
