@@ -1,7 +1,7 @@
 const assert = require('node:assert');
 const path = require('node:path');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'allows using the "preset" option with overrides',
 	options: {
 		treeshake: {
@@ -10,17 +10,21 @@ module.exports = {
 		},
 		plugins: [
 			{
+				name: 'test-plugin',
 				buildStart(options) {
+					if (!options.treeshake) {
+						throw new Error('Treeshaking options not found');
+					}
 					assert.strictEqual(options.treeshake.correctVarValueBeforeDeclaration, false);
 					assert.strictEqual(options.treeshake.propertyReadSideEffects, false);
 					assert.strictEqual(options.treeshake.tryCatchDeoptimization, false);
 					assert.strictEqual(options.treeshake.unknownGlobalSideEffects, true);
 					assert.strictEqual(
-						options.treeshake.moduleSideEffects(path.join(__dirname, 'dep.js')),
+						options.treeshake.moduleSideEffects(path.join(__dirname, 'dep.js'), false),
 						false
 					);
 				}
 			}
 		]
 	}
-};
+});
