@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'removes the last element of a sequence expression if it is unused'
-};
+});
