@@ -1,8 +1,8 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deactivates try-catch-deoptimization via option',
 	options: {
 		treeshake: {
 			tryCatchDeoptimization: false
 		}
 	}
-};
+});
