@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'retains side-effect-free code in try-statement-blocks'
-};
+});
