@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not retain side-effect-free code in functions called from try-statement-blocks'
-};
+});
