@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'supports core-js feature detection (#2869)'
-};
+});
