@@ -1,7 +1,7 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
 	function foo() { return 'foo'; }
 
 	assert.equal( foo(), 'foo' );
 
-});
+}));
