@@ -1,7 +1,7 @@
 (function (factory) {
   typeof define === 'function' && define.amd ? define(factory) :
   factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
   function foo() {
     return 'foo'
@@ -9,4 +9,4 @@
 
   assert.equal( foo(), 'foo' );
 
-})));
+}));
