@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not name unused-but-included default export'
-};
+});
