@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'properly remove unused function and class expressions'
-};
+});
