@@ -1,7 +1,7 @@
 (function (factory) {
     typeof define === 'function' && define.amd ? define(factory) :
     factory();
-}((function () { 'use strict';
+})((function () { 'use strict';
 
     function bar () { console.log("outer bar"); }
 
@@ -23,4 +23,4 @@
 
     console.log( getClass().name );
 
-})));
+}));
