@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'detect side-effects when dealing with update expressions'
-};
+});
