@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Correctly handles assignment operators on exports',
 	options: { output: { name: 'bundle' } }
-};
+});
