@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'use the original class name instead of renderName in class body'
-};
+});
