@@ -4,11 +4,7 @@
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.L));
 })(this, (function (L) { 'use strict';
 
-	function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }
-
-	var L__default = /*#__PURE__*/_interopDefaultLegacy(L);
-
-	L__default["default"].terminator = function(options) {
+	L.terminator = function(options) {
 	};
 
 }));
