@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'whitespace around the "." in member expressions does not mess up renaming'
-};
+});
