@@ -1,4 +1,4 @@
-define(function () { 'use strict';
+define((function () { 'use strict';
 
 	function yar() {
 		console.log('yar?');
@@ -6,4 +6,4 @@ define(function () { 'use strict';
 
 	yar();
 
-});
+}));
