@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'wraps simplified expressions that have become callees if necessary'
-};
+});
