@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Inserts space when simplifying yield expression without space'
-};
+});
