@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'Adds timing information to bundle when bundling with perf=true',
 	options: {
 		input: ['main.js', 'main2.js'],
@@ -17,4 +17,4 @@ module.exports = {
 			assert.ok(timings[timer][0] >= 0, 'Timer is not non-negative.');
 		}
 	}
-};
+});
