@@ -1,8 +1,8 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allow reserved identifiers via custom acorn options',
 	options: {
 		acorn: {
 			allowReserved: true
 		}
 	}
-};
+});
