@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'do not make assumptions about its value when using undefined as a parameter name'
-};
+});
