@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'imports external modules from nested internal modules',
 	options: {
 		external: ['path']
 	}
-};
+});
