@@ -1,7 +1,16 @@
-module.exports = {
+// @ts-check
+
+module.exports = defineTest({
 	description: 'throws when using both the amd.autoId and the amd.id option',
 	options: {
-		output: { dir: 'dist', amd: { autoId: 'a', id: 'a' } }
+		output: {
+			dir: 'dist',
+			amd: {
+				// @ts-expect-error expected error
+				autoId: 'a',
+				id: 'a'
+			}
+		}
 	},
 	generateError: {
 		code: 'INVALID_OPTION',
@@ -9,4 +18,4 @@ module.exports = {
 			'Invalid value for option "output.amd.id" - this option cannot be used together with "output.amd.autoId"/"output.amd.basePath".',
 		url: 'https://rollupjs.org/configuration-options/#output-amd-id'
 	}
-};
+});
