@@ -1,7 +1,13 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'throws when using only amd.basePath option',
 	options: {
-		output: { dir: 'dist', amd: { basePath: 'a' } }
+		output: {
+			dir: 'dist',
+			amd: {
+				// @ts-expect-error expected error
+				basePath: 'a'
+			}
+		}
 	},
 	generateError: {
 		code: 'INVALID_OPTION',
@@ -9,4 +15,4 @@ module.exports = {
 			'Invalid value for option "output.amd.basePath" - this option only works with "output.amd.autoId".',
 		url: 'https://rollupjs.org/configuration-options/#output-amd-basepath'
 	}
-};
+});
