@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not cause conflicts when deconflicting non-included parameters'
-};
+});
