@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description:
 		'do not hang when scanning for line-breaks in ASI prevention and there are comment-like strings'
-};
+});
