@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'tracks assigments nested in expressions that are included for other reasons'
-};
+});
