@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'tracks assigments included via try-catch-deoptimization'
-};
+});
