@@ -1,9 +1,9 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description:
 		'Associates arrow function parameters with their call arguments with regard to mutations',
 	exports(exports) {
 		assert.equal(exports.baz, 'present');
 	}
-};
+});
