@@ -1,8 +1,8 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'Associates method parameters with their call arguments with regard to mutations',
 	exports(exports) {
 		assert.equal(exports.bar, 'present');
 	}
-};
+});
