@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'uses the correct return value for async functions'
-};
+});
