@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'arrow function without braces returning a function (#1032)'
-};
+});
