@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Does not fail when iteratively chaining promises'
-};
+});
