@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'detects side-effects in chained string method arguments'
-};
+});
