@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles call of aliased external function (#957)',
 	warnings() {},
 	context: {
@@ -8,4 +8,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
