@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description:
 		'external function calls marked with pure comment do not have effects and should be removed even if parsed by PluginContext.parse method',
 	options: {
@@ -30,4 +30,4 @@ module.exports = {
 	code(code) {
 		assert.ok(code.search(/socks\(\)/) === -1);
 	}
-};
+});
