@@ -2,7 +2,7 @@ const assert = require('node:assert');
 const path = require('node:path');
 const ID_LIB = path.join(__dirname, 'lib.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'a module importing its own bindings',
 	exports(exports) {
 		assert.equal(exports.result, 4);
@@ -14,4 +14,4 @@ module.exports = {
 			message: 'Circular dependency: lib.js -> lib.js'
 		}
 	]
-};
+});
