@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'checks that entry is resolved',
 	options: {
 		input: 'not/a/path/that/actually/really/exists'
@@ -7,4 +7,4 @@ module.exports = {
 		code: 'UNRESOLVED_ENTRY',
 		message: 'Could not resolve entry module "not/a/path/that/actually/really/exists".'
 	}
-};
+});
