@@ -1,7 +1,7 @@
 const path = require('node:path');
 const ID_MAIN = path.join(__dirname, 'main.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'handles circular default exports',
 	warnings: [
 		{
@@ -10,4 +10,4 @@ module.exports = {
 			message: 'Circular dependency: main.js -> main.js'
 		}
 	]
-};
+});
