@@ -1,7 +1,7 @@
 const path = require('node:path');
 const ID_MAIN = path.join(__dirname, 'main.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'throws proper error for circular reexports',
 	error: {
 		code: 'CIRCULAR_REEXPORT',
@@ -9,4 +9,4 @@ module.exports = {
 		message: '"foo" cannot be exported from "main.js" as it is a reexport that references itself.',
 		watchFiles: [ID_MAIN]
 	}
-};
+});
