@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'includes variable mutations in class methods if tree-shaking is disabled',
 	options: {
 		treeshake: false
@@ -8,4 +8,4 @@ module.exports = {
 	async exports({ promise }) {
 		assert.strictEqual(await promise, 'ok');
 	}
-};
+});
