@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deoptimizes return values of class methods'
-};
+});
