@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not rename class methods incorrectly',
 	options: {
 		external: ['path']
 	}
-};
+});
