@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'preserves class names even if the class is renamed'
-};
+});
