@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'correctly imports the default from an entry point',
 	options: {
 		input: ['main', 'dep']
@@ -10,4 +10,4 @@ module.exports = {
 			value: 42
 		});
 	}
-};
+});
