@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'destructured parameters are properly renamed (#2418)'
-};
+});
