@@ -2,7 +2,7 @@ const path = require('node:path');
 const ID_F = path.join(__dirname, 'f.js');
 const ID_G = path.join(__dirname, 'g.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'Anonymous function declarations are hoisted',
 	warnings: [
 		{
@@ -11,4 +11,4 @@ module.exports = {
 			message: 'Circular dependency: f.js -> g.js -> f.js'
 		}
 	]
-};
+});
