@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'consistently deconflict variable names for parameter defaults'
-};
+});
