@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deconflicts top-level classes'
-};
+});
