@@ -1,8 +1,8 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'renames variables named "module" if necessary',
 	exports(exports) {
 		assert.equal(exports, 1);
 	}
-};
+});
