@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does bind export as default (#1078)'
-};
+});
