@@ -1,8 +1,8 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'handles default exports before a variable is declared',
 	exports(exports) {
 		assert.strictEqual(exports, undefined);
 	}
-};
+});
