@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'handles default function with id exports wrapped in parens'
-};
+});
