@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'default export of anonymous function'
-};
+});
