@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: '`delete` operator at the top level is preserved'
-};
+});
