@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'keeps conditional expressions if their test value is reassigned'
-};
+});
