@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'keeps logical expressions if the first part is reassigned'
-};
+});
