@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'keeps accesses to computed properties if their key is reassigned'
-};
+});
