@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'track deoptimizations of computed properties of empty objects'
-};
+});
