@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Throws for conflicts between manual chunks',
 	options: {
 		strictDeprecations: false,
@@ -15,4 +15,4 @@ module.exports = {
 		message: 'Cannot assign "dep.js" to the "dep2" chunk as it is already in the "dep1" chunk.'
 	},
 	warnings: []
-};
+});
