@@ -6,7 +6,7 @@ function getId(name) {
 	return path.join(__dirname, `${name}.js`);
 }
 
-module.exports = {
+module.exports = defineTest({
 	description: 'provides additional chunk information to a manualChunks function',
 	options: {
 		strictDeprecations: false,
@@ -312,4 +312,4 @@ module.exports = {
 		}
 	},
 	warnings: []
-};
+});
