@@ -6,7 +6,7 @@ const fsReadFile = fs.readFile;
 let currentReads = 0;
 let maxReads = 0;
 
-module.exports = {
+module.exports = defineTest({
 	description: 'maxParallelFileReads set to 3',
 	options: {
 		strictDeprecations: false,
@@ -34,4 +34,4 @@ module.exports = {
 			url: 'https://rollupjs.org/configuration-options/#maxparallelfileops'
 		}
 	]
-};
+});
