@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Inlining dynamic imports is not supported when preserving modules',
 	options: {
 		strictDeprecations: false,
@@ -12,4 +12,4 @@ module.exports = {
 			'Invalid value for option "output.inlineDynamicImports" - this option is not supported for "output.preserveModules".',
 		url: 'https://rollupjs.org/configuration-options/#output-inlinedynamicimports'
 	}
-};
+});
