@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Assigning manual chunks fails when preserving modules',
 	options: {
 		strictDeprecations: false,
@@ -16,4 +16,4 @@ module.exports = {
 			'Invalid value for option "output.manualChunks" - this option is not supported for "output.preserveModules".',
 		url: 'https://rollupjs.org/configuration-options/#output-manualchunks'
 	}
-};
+});
