@@ -4,7 +4,7 @@ const { getObject } = require('../../../../utils');
 
 const sideEffects = [];
 
-module.exports = {
+module.exports = defineTest({
 	description: 'does not include modules without used exports if moduleSideEffect is false',
 	context: {
 		sideEffects
@@ -91,4 +91,4 @@ module.exports = {
 			assert.strictEqual(warning.code, 'DEPRECATED_FEATURE');
 		}
 	}
-};
+});
