@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'marks the "output.dynamicImportFunction" option as deprecated',
 	options: {
 		output: {
@@ -11,4 +11,4 @@ module.exports = {
 			'The "output.dynamicImportFunction" option is deprecated. Use the "renderDynamicImport" plugin hook instead.',
 		url: 'https://rollupjs.org/plugin-development/#renderdynamicimport'
 	}
-};
+});
