@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'marks the "maxParallelFileReads" option as deprecated',
 	options: {
 		maxParallelFileReads: 3
@@ -9,4 +9,4 @@ module.exports = {
 			'The "maxParallelFileReads" option is deprecated. Use the "maxParallelFileOps" option instead.',
 		url: 'https://rollupjs.org/configuration-options/#maxparallelfileops'
 	}
-};
+});
