@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'marks the "output.preferConst" option as deprecated',
 	options: {
 		output: {
@@ -11,4 +11,4 @@ module.exports = {
 			'The "output.preferConst" option is deprecated. Use the "output.generatedCode.constBindings" option instead.',
 		url: 'https://rollupjs.org/configuration-options/#output-generatedcode-constbindings'
 	}
-};
+});
