@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'correctly deshadows destructured function parameters (#1008)'
-};
+});
