@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'shorthand properties referencing deshadowed variables are expanded'
-};
+});
