@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deshadows function expression ID (#1176)'
-};
+});
