@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not fail when non-integer arguments properties are accessed'
-};
+});
