@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'Dynamic import inlining when resolution id is a module in the bundle',
 	exports(exports) {
 		assert.equal(exports.y, 42);
@@ -8,4 +8,4 @@ module.exports = {
 			assert.equal(value, 84);
 		});
 	}
-};
+});
