@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description:
 		'correctly imports dynamic namespaces with only a default export from entry- and non-entry-point chunks',
 	options: {
@@ -11,4 +11,4 @@ module.exports = {
 			assert.deepStrictEqual(result, [{ __proto__: null, default: 42 }, { default: 42 }])
 		);
 	}
-};
+});
