@@ -1,7 +1,7 @@
 const path = require('node:path');
 const ID_MAIN = path.join(__dirname, 'main.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'throws if a dynamic relative import is not found',
 	error: {
 		code: 'UNRESOLVED_IMPORT',
@@ -10,4 +10,4 @@ module.exports = {
 		message: 'Could not resolve "./mod" from "main.js"',
 		watchFiles: [ID_MAIN]
 	}
-};
+});
