@@ -1,7 +1,7 @@
 const assert = require('node:assert');
 let referenceId;
 
-module.exports = {
+module.exports = defineTest({
 	description: 'supports emitting chunks as side effect of the manual chunks option',
 	options: {
 		output: {
@@ -19,4 +19,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
