@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'throws when accessing the file name before the asset source is set',
 	options: {
 		plugins: {
@@ -17,4 +17,4 @@ module.exports = {
 		plugin: 'test-plugin',
 		pluginCode: 'ASSET_NOT_FINALISED'
 	}
-};
+});
