@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'Throws when accessing the filename before it has been generated',
 	options: {
 		input: 'main.js',
@@ -18,4 +18,4 @@ module.exports = {
 		plugin: 'test-plugin',
 		pluginCode: 'CHUNK_NOT_GENERATED'
 	}
-};
+});
