@@ -1,6 +1,7 @@
 const assert = require('node:assert');
+const { pathToFileURL } = require('node:url');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'lists referenced files in the bundle',
 	options: {
 		input: 'main',
@@ -13,12 +14,16 @@ module.exports = {
 				})};\nexport const chunk = import.meta.ROLLUP_FILE_URL_${this.emitFile({
 					type: 'chunk',
 					id: 'ref.js'
+				})};\nexport const urlEncoding = import.meta.ROLLUP_FILE_URL_${this.emitFile({
+					type: 'chunk',
+					id: 'My%2FFile.js'
 				})}`;
 			},
 			generateBundle(options, bundle) {
 				assert.deepStrictEqual(bundle['main.js'].referencedFiles, [
 					'assets/asset.txt',
-					'chunks/ref.js'
+					'chunks/ref.js',
+					'chunks/My%2FFile.js'
 				]);
 			}
 		},
@@ -31,9 +36,11 @@ module.exports = {
 		__dirname: 'dir'
 	},
 	exports(exports) {
+		const directoryURL = pathToFileURL('dir');
 		assert.deepStrictEqual(exports, {
-			asset: 'file:///dir/assets/asset.txt',
-			chunk: 'file:///dir/chunks/ref.js'
+			asset: `${directoryURL}/assets/asset.txt`,
+			chunk: `${directoryURL}/chunks/ref.js`,
+			urlEncoding: `${directoryURL}/chunks/My%252FFile.js`
 		});
 	}
-};
+});
