@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'It is not necessary to provide an input if a dynamic entry is emitted',
 	options: {
 		input: undefined,
@@ -9,4 +9,4 @@ module.exports = {
 			}
 		}
 	}
-};
+});
