@@ -1,6 +1,6 @@
 let referenceId;
 
-module.exports = {
+module.exports = defineTest({
 	description: 'throws when trying to set file sources in  the outputOptions hook',
 	options: {
 		input: 'main',
@@ -21,4 +21,4 @@ module.exports = {
 		plugin: 'at position 1',
 		pluginCode: 'CANNOT_EMIT_FROM_OPTIONS_HOOK'
 	}
-};
+});
