@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'empty imports are assumed to contain side-effects'
-};
+});
