@@ -1,6 +1,6 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows `export *` from external module, internally',
 	options: {
 		external: ['path']
 	}
-};
+});
