@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'allows export { x as y }'
-};
+});
