@@ -1,8 +1,8 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'correctly exports deconflicted names',
 	exports(exports) {
 		assert.equal(exports.bar(), 'bar');
 	}
-};
+});
