@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'exports default-as-named from sibling module (b)'
-};
+});
