@@ -1,8 +1,8 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'exports default-as-named from sibling module',
 	exports(exports) {
 		assert.equal(exports.foo, 'FOO');
 	}
-};
+});
