@@ -1,7 +1,7 @@
 const assert = require('node:assert');
 const path = require('node:path');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'ensures external modules have correct names',
 	options: {
 		external: ['path']
@@ -9,4 +9,4 @@ module.exports = {
 	exports(exports) {
 		assert.equal(exports, path.sep);
 	}
-};
+});
