@@ -1,8 +1,8 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'exports a default named function',
 	exports(exports) {
 		assert.equal(exports(), 42);
 	}
-};
+});
