@@ -1,7 +1,7 @@
 const assert = require('node:assert');
 const path = require('node:path');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'exports directly from an external module',
 	options: {
 		external: ['path']
@@ -9,6 +9,6 @@ module.exports = {
 	exports(exports) {
 		assert.equal(exports.sep, path.sep);
 	}
-};
+});
 
 // https://github.com/esperantojs/esperanto/issues/161
