@@ -5,10 +5,10 @@ const assert = require('node:assert');
 // see https://github.com/acornjs/acorn/issues/806
 // Consider reverting this change should this become an acorn option
 
-module.exports = {
+module.exports = defineTest({
 	description: '"variables corresponding to globals can be exported"',
 
 	exports(exports) {
 		assert.equal(exports.Buffer, Buffer);
 	}
-};
+});
