@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'side-effects are preserved if subject is exported in multiple ways (#733)'
-};
+});
