@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'cannot have named exports if explicit export type is default',
 	options: { output: { exports: 'default' } },
 	generateError: {
@@ -7,4 +7,4 @@ module.exports = {
 			'"default" was specified for "output.exports", but entry module "main.js" has the following exports: "foo"',
 		url: 'https://rollupjs.org/configuration-options/#output-exports'
 	}
-};
+});
