@@ -1,7 +1,7 @@
 const path = require('node:path');
 const ID_MAIN = path.join(__dirname, 'main.js');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'external paths from custom resolver remain external (#633)',
 	options: {
 		external: (_id, parent) => parent === 'dep',
@@ -22,4 +22,4 @@ module.exports = {
 		message:
 			'"dep" is imported as an external by "dep", but is already an existing non-external module id.'
 	}
-};
+});
