@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'throws for entry points that are resolved as false by plugins',
 	options: {
 		plugins: {
@@ -11,4 +11,4 @@ module.exports = {
 		code: 'UNRESOLVED_ENTRY',
 		message: 'Entry module "main.js" cannot be external.'
 	}
-};
+});
