@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'external function ignores \\0 started ids',
 	options: {
 		external(id) {
@@ -26,4 +26,4 @@ module.exports = {
 			}
 		]
 	}
-};
+});
