@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'calls to externally reassigned methods of default exports must be retained',
 	exports(exports) {
 		let triggered = false;
@@ -10,4 +10,4 @@ module.exports = {
 		exports.test();
 		assert.ok(triggered);
 	}
-};
+});
