@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'deoptimizes "this" for accessors triggered by for-in loops'
-};
+});
