@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'uses correct scope in for statement (#1538)'
-};
+});
