@@ -1,9 +1,9 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'includes for-loop parameters',
 	exports({ checkObject, checkArray }) {
 		assert.strictEqual(checkObject({ foo: 1 }), 1, 'object');
 		assert.strictEqual(checkArray([2]), 2, 'array');
 	}
-};
+});
