@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'uses parent scope for right-hand-side in for-of statement (#1539)'
-};
+});
