@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'renames function expression IDs correctly'
-};
+});
