@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'globally called function should be included if it modifies an exported value (#112)'
-};
+});
