@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'do not fail when using labels inside functions (#1706)'
-};
+});
