@@ -1,6 +1,6 @@
 const assert = require('node:assert');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'handles statically resolvable "if" statements (#2134)',
 	context: {
 		value: 1
@@ -8,4 +8,4 @@ module.exports = {
 	exports({ x }) {
 		assert.equal(x, 1);
 	}
-};
+});
