@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'does not fail for double declarations with initializers from other modules'
-};
+});
