@@ -1,7 +1,7 @@
 const assert = require('node:assert');
 const path = require('node:path');
 
-module.exports = {
+module.exports = defineTest({
 	description: 'reports if a module has a default export',
 	options: {
 		plugins: [
@@ -42,4 +42,4 @@ module.exports = {
 			}
 		]
 	}
-};
+});
