@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'throws when the maximum hash size is exceeded',
 	options: { output: { chunkFileNames: '[hash:3].js' } },
 	generateError: {
@@ -6,4 +6,4 @@ module.exports = {
 		message:
 			'To generate hashes for this number of chunks (currently 1), you need a minimum hash size of 6, received 3. Check the "output.chunkFileNames" option.'
 	}
-};
+});
