@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'updates to names are preserved (#930)'
-};
+});
