@@ -1,5 +1,5 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'imports a default class'
-};
+});
 
 // test copied from https://github.com/esnext/es6-module-transpiler/tree/master/test/examples/export-default-class
