@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'imports a default function'
-};
+});
