@@ -1,3 +1,3 @@
-module.exports = {
+module.exports = defineTest({
 	description: 'imports a dependency from a separate module'
-};
+});
