@@ -2,7 +2,7 @@ const assert = require('node:assert');
 const path = require('node:path');
 const URL = require('node:url').URL;
 
-module.exports = {
+module.exports = defineTest({
 	description: 'resolves import.meta.url',
 	context: {
 		__filename: path.join(__dirname, 'main.js')
@@ -10,4 +10,4 @@ module.exports = {
 	exports(exports) {
 		assert.strictEqual(exports, new URL('file:' + path.join(__dirname, 'main.js')).href);
 	}
-};
+});
